@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -34,4 +34,8 @@ public @interface Property {
 
 	String value() default "";
 
+	String min() default "";
+
+	String max() default "";
+
 }
