@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,6 +23,6 @@
 
 package ch.kuramo.javie.api.plugin;
 
-public interface JaviePlugin {
+public abstract class JaviePlugin {
 
 }
