@@ -98,6 +98,7 @@ public class Activator extends AbstractUIPlugin {
 		JsonicBugFix.patch();
 		DragSourceEnhancement.patch();
 		DropTargetEnhancement.patch();
+		TreeViewerEditorEnhancement.patch();
 		ColorDialogBugFix.patch();
 
 		createDefaultConsole();
@@ -166,8 +167,6 @@ public class Activator extends AbstractUIPlugin {
 	public static final String IMG_KF_LINEAR_SELECT			= "IMG_KF_LINEAR_SELECT";
 	public static final String IMG_KF_CATMULL_ROM			= "IMG_KF_CATMULL_ROM";
 	public static final String IMG_KF_CATMULL_ROM_SELECT	= "IMG_KF_CATMULL_ROM_SELECT";
-	public static final String IMG_KF_SLERP					= "IMG_KF_SLERP";
-	public static final String IMG_KF_SLERP_SELECT			= "IMG_KF_SLERP_SELECT";
 
 	public static final String IMG_STOPWATCH_NO_KF	= "IMG_STOPWATCH_NO_KF";
 	public static final String IMG_STOPWATCH_HAS_KF	= "IMG_STOPWATCH_HAS_KF";
@@ -206,8 +205,6 @@ public class Activator extends AbstractUIPlugin {
 		registerImage(reg, IMG_KF_LINEAR_SELECT, "kf_linear_select.png");
 		registerImage(reg, IMG_KF_CATMULL_ROM,        "kf_catmull_rom.png");
 		registerImage(reg, IMG_KF_CATMULL_ROM_SELECT, "kf_catmull_rom_select.png");
-		registerImage(reg, IMG_KF_SLERP,        "kf_slerp.png");
-		registerImage(reg, IMG_KF_SLERP_SELECT, "kf_slerp_select.png");
 
 		registerImage(reg, IMG_STOPWATCH_NO_KF,  "stopwatch_no_kf.png");
 		registerImage(reg, IMG_STOPWATCH_HAS_KF, "stopwatch_has_kf.png");
