@@ -50,8 +50,6 @@ public class ImageUtil {
 
 	private static final RGB RGB_BLACK = new RGB(0, 0, 0);
 
-	private static final Color COLOR_BLACK = new Color(0, 0, 0);
-
 
 	private static ImageRegistry getRegistry() {
 		return Activator.getDefault().getImageRegistry();
@@ -145,7 +143,7 @@ public class ImageUtil {
 	}
 
 	public static Image getNullIcon() {
-		return getColorIcon(COLOR_BLACK);
+		return getColorIcon(Color.BLACK);
 	}
 
 	public static Image getTextIcon() {
