@@ -47,9 +47,11 @@ import org.eclipse.swt.widgets.FileDialog;
 import org.eclipse.ui.IWorkbenchWindow;
 
 import ch.kuramo.javie.api.ColorMode;
+import ch.kuramo.javie.api.IArray;
 import ch.kuramo.javie.api.RenderResolution;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
+import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.app.CommandIds;
 import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.app.project.ProjectManager;
@@ -61,7 +63,6 @@ import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Project;
 import ch.kuramo.javie.core.ProjectDecodeException;
 import ch.kuramo.javie.core.VideoBuffer;
-import ch.kuramo.javie.core.services.ArrayPools;
 import ch.kuramo.javie.core.services.ProjectDecoder;
 import ch.kuramo.javie.core.services.ProjectEncoder;
 import ch.kuramo.javie.core.services.VideoRenderContext;
@@ -85,7 +86,7 @@ public class SequenceOutputAction extends Action {
 	private VideoRenderContext vrContext;
 
 	@Inject
-	private ArrayPools _arrayPools;
+	private IArrayPools _arrayPools;
 
 
 	public SequenceOutputAction(LayerCompositionView view) {
@@ -199,8 +200,7 @@ public class SequenceOutputAction extends Action {
 
 			vrContext.activate();
 			try {
-				// TODO これはループの外で良いんだっけ？　良いはずだが自信無し。要確認
-				comp.prepareExpression(vrContext.createInitialExpressionScope());
+				comp.prepareExpression(vrContext.createInitialExpressionScope(comp));
 
 				for (long i = 0; i < numFrames; ++i) {
 					if (monitor.isCanceled()) {
@@ -263,7 +263,8 @@ public class SequenceOutputAction extends Action {
 						ImageIO.write(image, "png", file);
 
 					} else {
-						byte[] array2 = _arrayPools.getByteArray(width*height*3);
+						IArray<byte[]> pa = _arrayPools.getByteArray(width*height*3);
+						byte[] array2 = pa.getArray();
 						try {
 							for (int i = 0, n = width*height; i < n; ++i) {
 								array2[i*3  ] = array[i*4  ];
@@ -279,7 +280,7 @@ public class SequenceOutputAction extends Action {
 							BufferedImage image = new BufferedImage(cm, wr, false, null);
 							ImageIO.write(image, "bmp", file);
 						} finally {
-							_arrayPools.put(array2);
+							pa.release();
 						}
 					}
 					break;
