@@ -90,6 +90,8 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 
 	private Time _frameDuration;
 
+	private volatile boolean _hidden = true;
+
 	private volatile boolean _dirty;
 
 
@@ -417,6 +419,21 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 		}
 	}
 
+	public void setHidden(boolean hidden) {
+		if (_hidden != hidden) {
+			_hidden = hidden;
+
+			if (hidden && !_timeKeeper.isPaused()) {
+				pause();
+			} else if (!hidden && _dirty) {
+				_dirty = false;
+				if (_videoCanvas != null) {
+					_videoCanvas.forceRender();
+				}
+			}
+		}
+	}
+
 
 	private final ListenerList _playerLinkListeners = new ListenerList();
 
@@ -439,21 +456,17 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 		Time time = event.time;
 
 		_timeKeeper.setTime(time);
-		if (_audioThread != null && !_timeKeeper.isPaused()) {
-			_audioThread.setTime(time);
+		if (_hidden) {
+			_dirty = true;
+			notifyPlayerTime(time);
+		} else {
+			if (_audioThread != null && !_timeKeeper.isPaused()) {
+				_audioThread.setTime(time);
+			}
+			if (_videoCanvas != null && _timeKeeper.isPaused()) {
+				_videoCanvas.forceRender();
+			}
 		}
-		if (_videoCanvas != null && _timeKeeper.isPaused()) {
-			_videoCanvas.forceRender();
-		}
-
-		// オーディオのみの場合は次の処理が必要になるはずだが、
-		// プレーヤーをリンクするのはコンポジションの場合だけなので、
-		// オーディオのみということは無いはず。
-		//
-		//if (_videoCanvas == null && _timeKeeper.isPaused()) {
-		//	updateScale();
-		//	firePlayerTime();
-		//}
 	}
 
 	public void handleProjectEvent(ProjectEvent event) {
@@ -478,7 +491,7 @@ public class MediaPlayer extends Composite implements PlayerThreadListener, Play
 
 			case SHADOW_OPERATION_EXECUTION:
 				// このイベントは ShadowOperationRunner のスレッド上で送信される。
-				if (isSameProject(event.getProjectManager().getShadow()) && _dirty) {
+				if (isSameProject(event.getProjectManager().getShadow()) && !_hidden && _dirty) {
 					_dirty = false;
 					if (_videoCanvas != null && _timeKeeper.isPaused()) {
 						_videoCanvas.forceRender();
