@@ -548,12 +548,11 @@ public class VideoCanvas extends Thread implements GLEventListener {
 				Time time = TIME0;
 				_vrContext.reset();
 				_vrContext.setRenderResolution(resolution);
-				_vrContext.setTime(time);
 				_vrContext.setColorMode(ColorMode.RGBA8);
 
 				VideoBuffer vb = null;
 				try {
-					vb = _mediaInput.getVideoFrameImage();
+					vb = _mediaInput.getVideoFrameImage(time);
 				} catch (Exception e) {
 					_logger.error("error getting video frame", e);
 				} catch (InternalError e) {
@@ -644,7 +643,6 @@ public class VideoCanvas extends Thread implements GLEventListener {
 
 				_vrContext.reset();
 				_vrContext.setRenderResolution(resolution);
-				_vrContext.setTime(frameTime);
 				_vrContext.setColorMode(ColorMode.RGBA8);
 
 				VideoBuffer vb = null;
@@ -655,9 +653,9 @@ public class VideoCanvas extends Thread implements GLEventListener {
 					try {
 						// TODO prepareExpressionはプロジェクトに構造的な変更があった場合のみ行えばよい。
 						Composition comp = ((CompositionItem) _mediaItem).getComposition();
-						comp.prepareExpression(_vrContext.createInitialExpressionScope());
+						comp.prepareExpression(_vrContext.createInitialExpressionScope(comp));
 
-						vb = _mediaInput.getVideoFrameImage();
+						vb = _mediaInput.getVideoFrameImage(frameTime);
 					} catch (Exception e) {
 						_logger.error("error getting video frame", e);
 					} catch (InternalError e) {
@@ -668,7 +666,7 @@ public class VideoCanvas extends Thread implements GLEventListener {
 					}
 				} else {
 					try {
-						vb = _mediaInput.getVideoFrameImage();
+						vb = _mediaInput.getVideoFrameImage(frameTime);
 					} catch (Exception e) {
 						_logger.error("error getting video frame", e);
 					} catch (InternalError e) {
