@@ -40,6 +40,7 @@ import org.eclipse.core.runtime.Platform;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.GroupMarker;
 import org.eclipse.jface.action.MenuManager;
+import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.util.LocalSelectionTransfer;
 import org.eclipse.jface.viewers.CellEditor;
 import org.eclipse.jface.viewers.EditingSupport;
@@ -112,8 +113,11 @@ import ch.kuramo.javie.app.UIUtil;
 import ch.kuramo.javie.app.actions.AVIOutputAction;
 import ch.kuramo.javie.app.actions.AddEffectAction;
 import ch.kuramo.javie.app.actions.AddExpressionsAction;
+import ch.kuramo.javie.app.actions.KeyframeInterpolationAction;
 import ch.kuramo.javie.app.actions.QTMovieOutputAction;
 import ch.kuramo.javie.app.actions.RemoveKeyframesAction;
+import ch.kuramo.javie.app.actions.ResetAnimatableValuesAction;
+import ch.kuramo.javie.app.actions.ReverseLayerTimeAction;
 import ch.kuramo.javie.app.actions.SequenceOutputAction;
 import ch.kuramo.javie.app.actions.TimeRemapAction;
 import ch.kuramo.javie.app.actions.WaveOutputAction;
@@ -148,6 +152,7 @@ import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.EffectDescriptor;
 import ch.kuramo.javie.core.EffectableLayer;
 import ch.kuramo.javie.core.Folder;
+import ch.kuramo.javie.core.Interpolation;
 import ch.kuramo.javie.core.Item;
 import ch.kuramo.javie.core.ItemLayer;
 import ch.kuramo.javie.core.Keyframe;
@@ -657,20 +662,28 @@ public class LayerCompositionView extends ViewPart
 		MenuManager timeMenu = new MenuManager("時間");
 		MenuManager effectMenu = new MenuManager("エフェクト");
 		MenuManager animeMenu = new MenuManager("アニメーション");
+		MenuManager interpolationMenu = new MenuManager("キーフレーム補間法");
 
 		menuMgr.add(newMenu);
 		menuMgr.add(timeMenu);
 		menuMgr.add(effectMenu);
 		menuMgr.add(animeMenu);
+		menuMgr.add(new Separator());
+		menuMgr.add(new ResetAnimatableValuesAction(window, _treeViewer));
 		menuMgr.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
 
 		newMenu.add(_newCameraLayerAction);
 		newMenu.add(_newNullLayerAction);
 		newMenu.add(_newTextLayerAction);
 		timeMenu.add(new TimeRemapAction(window, _treeViewer));
+		timeMenu.add(new ReverseLayerTimeAction(_treeViewer));
 		setupEffectContextMenu(effectMenu, effectActions);
+		animeMenu.add(interpolationMenu);
 		animeMenu.add(new RemoveKeyframesAction(_treeViewer));
 		animeMenu.add(new AddExpressionsAction(window, _treeViewer));
+		interpolationMenu.add(new KeyframeInterpolationAction(_treeViewer, Interpolation.HOLD));
+		interpolationMenu.add(new KeyframeInterpolationAction(_treeViewer, Interpolation.LINEAR));
+		interpolationMenu.add(new KeyframeInterpolationAction(_treeViewer, Interpolation.CATMULL_ROM));
 
 		getSite().registerContextMenu(menuMgr, _treeViewer);
 
@@ -1286,7 +1299,7 @@ public class LayerCompositionView extends ViewPart
 		_collector.setTime(time);
 
 		// TODO prepareExpressionはプロジェクトに構造的な変更があった場合のみ行えばよい。
-		_composition.prepareExpression(_collector.createInitialExpressionScope());
+		_composition.prepareExpression(_collector.createInitialExpressionScope(_composition));
 
 		_treeViewer.setData(ANIMATABLE_VALUES, _collector.collect());
 		updateProperties();
