@@ -28,8 +28,8 @@ import org.eclipse.jface.action.Separator;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.ui.IActionBars;
-import org.eclipse.ui.IPartListener;
-import org.eclipse.ui.IWorkbenchPart;
+import org.eclipse.ui.IPartListener2;
+import org.eclipse.ui.IWorkbenchPartReference;
 import org.eclipse.ui.part.ViewPart;
 
 import ch.kuramo.javie.app.player.MediaPlayer;
@@ -42,7 +42,7 @@ import ch.kuramo.javie.app.project.ProjectManager;
 import ch.kuramo.javie.core.CompositionItem;
 import ch.kuramo.javie.core.MediaItem;
 
-public class MediaPlayerView extends ViewPart implements IPartListener {
+public class MediaPlayerView extends ViewPart implements IPartListener2 {
 
 	public static final String ID = "ch.kuramo.javie.app.views.mediaPlayerView";
 
@@ -132,25 +132,41 @@ public class MediaPlayerView extends ViewPart implements IPartListener {
 		return _pinAction.isChecked();
 	}
 
-	public void partClosed(IWorkbenchPart part) {
-		if (part == this) {
+	public void partOpened(IWorkbenchPartReference partRef) {
+		// nothing to do
+	}
+
+	public void partClosed(IWorkbenchPartReference partRef) {
+		if (partRef.getPart(false) == this) {
 			_mediaPlayer.close();
 		}
 	}
 
-	public void partOpened(IWorkbenchPart part) {
+	public void partVisible(IWorkbenchPartReference partRef) {
+		if (partRef.getPart(false) == this) {
+			_mediaPlayer.setHidden(false);
+		}
+	}
+
+	public void partHidden(IWorkbenchPartReference partRef) {
+		if (partRef.getPart(false) == this) {
+			_mediaPlayer.setHidden(true);
+		}
+	}
+
+	public void partActivated(IWorkbenchPartReference partRef) {
 		// nothing to do
 	}
 
-	public void partActivated(IWorkbenchPart part) {
+	public void partDeactivated(IWorkbenchPartReference partRef) {
 		// nothing to do
 	}
 
-	public void partDeactivated(IWorkbenchPart part) {
+	public void partBroughtToTop(IWorkbenchPartReference partRef) {
 		// nothing to do
 	}
 
-	public void partBroughtToTop(IWorkbenchPart part) {
+	public void partInputChanged(IWorkbenchPartReference partRef) {
 		// nothing to do
 	}
 
