@@ -354,7 +354,9 @@ public class LayerElement extends Element {
 					modeEditor.setLabelProvider(new BlendModeLabelProvider());
 					modeEditor.setActivationStyle(ComboBoxViewerCellEditor.DROP_DOWN_ON_PROGRAMMATIC_ACTIVATION);
 
-					((Combo) modeEditor.getControl()).addSelectionListener(new SelectionAdapter() {
+					Combo combo = (Combo) modeEditor.getControl();
+					combo.setVisibleItemCount(35);
+					combo.addSelectionListener(new SelectionAdapter() {
 						public void widgetSelected(SelectionEvent e) {
 							setCellEditorValue(LayerCompositionView.MODE_COL, modeEditor.getValue());
 						}
@@ -413,7 +415,7 @@ public class LayerElement extends Element {
 				return (parent != null) ? parent : NO_PARENT;
 
 			default:
-				return true;
+				return null;
 		}
 	}
 
