@@ -23,6 +23,7 @@
 
 package ch.kuramo.javie.app.views.layercomp;
 
+import java.util.Collections;
 import java.util.List;
 import java.util.Map;
 import java.util.SortedMap;
@@ -54,6 +55,7 @@ import ch.kuramo.javie.app.ImageUtil;
 import ch.kuramo.javie.app.InjectorHolder;
 import ch.kuramo.javie.app.PropertyUtil;
 import ch.kuramo.javie.app.project.LayerSlipOperation;
+import ch.kuramo.javie.app.project.ModifyKeyframeInterpolationOperation;
 import ch.kuramo.javie.app.project.ModifyLayerInPointOperation;
 import ch.kuramo.javie.app.project.ModifyLayerOutPointOperation;
 import ch.kuramo.javie.app.project.ProjectManager;
@@ -65,6 +67,7 @@ import ch.kuramo.javie.app.views.LayerCompositionView;
 import ch.kuramo.javie.core.AnimatableValue;
 import ch.kuramo.javie.core.Effect;
 import ch.kuramo.javie.core.EffectableLayer;
+import ch.kuramo.javie.core.Interpolation;
 import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.Keyframe;
 import ch.kuramo.javie.core.Layer;
@@ -629,6 +632,10 @@ public class TimelineManager {
 		return keyframeSelection.size() > 0;
 	}
 
+	public Map<Keyframe<?>, AnimatableValueElement> getKeyframeSelection() {
+		return Collections.unmodifiableMap(keyframeSelection);
+	}
+
 	private Object[][] createSelectedKeyframeData() {
 		Object[][] data = new Object[keyframeSelection.size()][];
 
@@ -697,6 +704,11 @@ public class TimelineManager {
 				projectManager, composition, createSelectedKeyframeData()));
 	}
 
+	public void modifySelectedKeyframeInterpolation(Interpolation newInterpolation) {
+		projectManager.postOperation(new ModifyKeyframeInterpolationOperation(
+				projectManager, composition, createSelectedKeyframeData(), newInterpolation));
+	}
+
 	public void setWrapMode(boolean wrapMode) {
 		this.wrapMode = wrapMode;
 	}
