@@ -33,6 +33,7 @@ import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Text;
 
 import ch.kuramo.javie.api.ColorMode;
@@ -40,6 +41,7 @@ import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.app.widgets.FrameRateComboUtil;
 import ch.kuramo.javie.app.widgets.GridBuilder;
 import ch.kuramo.javie.core.FrameDuration;
+import ch.kuramo.javie.core.TimeCode;
 
 public class CompositionWizardPage extends WizardPage {
 
@@ -60,6 +62,8 @@ public class CompositionWizardPage extends WizardPage {
 
 	private Text _durationText;
 
+	private Label _duration2;
+
 	private Combo _colorModeCombo;
 
 	private ModifyListener _modifyListener;
@@ -105,8 +109,8 @@ public class CompositionWizardPage extends WizardPage {
 
 							gb.hSpan(4).hAlign(SWT.RIGHT).hGrab().label(SWT.NULL, "デュレーション:");
 		_durationText =		gb.hSpan(3).hAlign(SWT.FILL).hGrab()
-								.text(SWT.BORDER, String.valueOf(_settings.duration.toFrameNumber(_settings.frameDuration)));
-							gb.hSpan(9).hGrab().label(SWT.NULL, "フレーム");
+								.text(SWT.BORDER, TimeCode.toTimeCode(_settings.duration, _settings.frameDuration));
+		_duration2 =		gb.hSpan(9).hAlign(SWT.FILL).hGrab().label(SWT.NULL, "");
 
 							gb.hSpan(16).size(10, 10).composite(SWT.NULL);
 
@@ -229,16 +233,24 @@ public class CompositionWizardPage extends WizardPage {
 			setErrorMessage("デュレーションが入力されていません。");
 			return;
 		}
-		int duration = 0;
-		try {
-			duration = Integer.parseInt(durationStr);
-		} catch (NumberFormatException e) {
-		}
-		if (duration <= 0) {
-			setErrorMessage("デュレーションには1以上の整数を入力してください。");
+		Time frameDuration = FrameRateComboUtil.toFrameDuration(fpsStr);
+		long frames = TimeCode.parseTimeCode(durationStr, frameDuration);
+		if (frames <= 0) {
+			setErrorMessage("0以下のデュレーションは入力できません。");
 			return;
 		}
 
+		String timeCode = TimeCode.toTimeCode(Time.fromFrameNumber(frames, frameDuration), frameDuration);
+		int base = (int)Math.round((double)frameDuration.timeScale / frameDuration.timeValue);
+		boolean drop = (timeCode.indexOf(';') != -1);
+		_duration2.setText(String.format("= %s (ベース %d%s) , %dフレーム", timeCode, base, drop ? "ドロップ" : "", frames));
+
+		if (control == _fpsCombo && !durationStr.matches("[\\d]+")) {
+			_durationText.removeModifyListener(_modifyListener);
+			_durationText.setText(timeCode);
+			_durationText.addModifyListener(_modifyListener);
+		}
+
 
 		setErrorMessage(null);
 		setPageComplete(true);
@@ -259,11 +271,15 @@ public class CompositionWizardPage extends WizardPage {
 		}
 
 		CompositionSettings result = new CompositionSettings();
+
+		Time frameDuration = FrameRateComboUtil.toFrameDuration(_fpsCombo.getText().trim());
+		long frames = TimeCode.parseTimeCode(_durationText.getText().trim(), frameDuration);
+
 		result.name = _nameText.getText().trim();
 		result.width = Integer.parseInt(_widthText.getText().trim());
 		result.height = Integer.parseInt(_heightText.getText().trim());
-		result.frameDuration = FrameRateComboUtil.toFrameDuration(_fpsCombo.getText().trim());
-		result.duration = Time.fromFrameNumber(Integer.valueOf(_durationText.getText().trim()), result.frameDuration);
+		result.frameDuration = frameDuration;
+		result.duration = Time.fromFrameNumber(frames, frameDuration);
 		result.colorMode = ColorMode.values()[_colorModeCombo.getSelectionIndex()];
 		return result;
 	}
@@ -280,7 +296,7 @@ class CompositionSettings implements Cloneable {
 
 	Time frameDuration = FrameDuration.FPS_29_97;
 
-	Time duration = Time.fromFrameNumber(4000, frameDuration);
+	Time duration = Time.fromFrameNumber(1800, frameDuration);
 
 	ColorMode colorMode = ColorMode.RGBA8;
 
