@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -24,7 +24,6 @@
 package ch.kuramo.javie.core;
 
 import java.util.Collection;
-import java.util.Set;
 
 import org.mozilla.javascript.Context;
 import org.mozilla.javascript.NativeJavaArray;
@@ -32,21 +31,23 @@ import org.mozilla.javascript.ScriptRuntime;
 import org.mozilla.javascript.Scriptable;
 
 import ch.kuramo.javie.api.Color;
-import ch.kuramo.javie.api.plugin.PIAnimatableColor;
+import ch.kuramo.javie.api.IAnimatableColor;
 import ch.kuramo.javie.core.exprelems.DoubleProperty;
 
-public class AnimatableColor extends AbstractAnimatableValue<Color> implements PIAnimatableColor {
-
-	private static final Set<Interpolation> SUPPORTED_INTERPOLATIONS = Util.unmodifiableSet(
-			Interpolation.HOLD, Interpolation.LINEAR, Interpolation.CATMULL_ROM);
-
+public class AnimatableColor extends ArithmeticalAnimatableValue<Color> implements IAnimatableColor {
 
 	public AnimatableColor(Color staticValue, Collection<Keyframe<Color>> keyframes, String expression) {
-		super(staticValue, keyframes, expression);
+		super(staticValue, keyframes, expression, Color.COLORLESS_TRANSPARENT, Color.WHITE);
 	}
 
-	public AnimatableColor(Color staticValue) {
-		super(staticValue);
+	public AnimatableColor(Color defaultValue) {
+		super(defaultValue, Color.COLORLESS_TRANSPARENT, Color.WHITE);
+	}
+
+	@Override
+	public Color clamp(Color value) {
+		// Colorクラスは自身のコンストラクタで値の範囲をクランプしているのでそのまま返す。
+		return value;
 	}
 
 	public Color jsToJava(Object jsValue) {
@@ -85,11 +86,6 @@ public class AnimatableColor extends AbstractAnimatableValue<Color> implements P
 		return new Color(d[0], d[1], d[2], d[3]);
 	}
 
-	@Override
-	public Set<Interpolation> supportedInterpolations() {
-		return SUPPORTED_INTERPOLATIONS;
-	}
-
 	public Scriptable[] createExpressionElement(final RenderContext renderContext) {
 		DoubleProperty r = new DoubleProperty() {
 			public double getValue()			{ return value(renderContext).r; }
