@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -32,8 +32,14 @@ public interface TextLayer extends MediaLayer {
 
 	AnimatableString getSourceText();
 
+	AnimatableString getFont();
+
 	AnimatableInteger getFontSize();
 
 	AnimatableColor getFillColor();
 
+	AnimatableHorizontalAlignment getHorizontalAlignment();
+
+	AnimatableDouble getLeading();
+
 }
