@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,6 +27,6 @@ public interface VectorMediaInput extends MediaInput {
 
 	void rasterize(
 			VideoBuffer resultBuffer, DepthBuffer depthBuffer,
-			double[] mvMatrix, double[] prjMatrix, double opacity);
+			double[] mvMatrix, double[] prjMatrix);
 
 }
