@@ -26,12 +26,15 @@ package ch.kuramo.javie.core.internal;
 import java.util.Collections;
 import java.util.List;
 
+import ch.kuramo.javie.api.AudioMode;
+import ch.kuramo.javie.api.IObjectArray;
 import ch.kuramo.javie.api.RenderResolution;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.core.AbstractTransformableLayer;
 import ch.kuramo.javie.core.AnimatableDouble;
 import ch.kuramo.javie.core.AnimatableString;
@@ -87,11 +90,11 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 	private AnimatableString _intersectionGroup = new AnimatableString("");
 
-	private AnimatableDouble _opacity = new AnimatableDouble(100d);
+	private AnimatableDouble _opacity = new AnimatableDouble(100d, 0d, 100d);
 
 	private BlendMode _blendMode = BlendMode.NORMAL;
 
-	private AnimatableVec2d _audioLevels = new AnimatableVec2d(new Vec2d(0, 0));
+	private AnimatableVec2d _audioLevels = new AnimatableVec2d(Vec2d.ZERO, new Vec2d(-48, -48), new Vec2d(48, 48));
 
 	private AnimatableDouble _timeRemap = new AnimatableDouble(0.0);
 
@@ -113,6 +116,9 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	@Inject
 	private AudioEffectPipeline _aePipeline;
 
+	@Inject
+	private IArrayPools _arrayPools;
+
 
 	@Override
 	public void initialize() {
@@ -198,6 +204,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	public void setDepthBase(AnimatableVec2d depthBase) {
+		depthBase.copyConfigurationFrom(_depthBase);
 		_depthBase = depthBase;
 	}
 
@@ -206,6 +213,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	public void setIntersectionGroup(AnimatableString intersectionGroup) {
+		intersectionGroup.copyConfigurationFrom(_intersectionGroup);
 		_intersectionGroup = intersectionGroup;
 	}
 
@@ -214,6 +222,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	public void setOpacity(AnimatableDouble opacity) {
+		opacity.copyConfigurationFrom(_opacity);
 		_opacity = opacity;
 	}
 
@@ -230,6 +239,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	public void setAudioLevels(AnimatableVec2d audioLevels) {
+		audioLevels.copyConfigurationFrom(_audioLevels);
 		_audioLevels = audioLevels;
 	}
 
@@ -238,6 +248,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 	}
 
 	public void setTimeRemap(AnimatableDouble timeRemap) {
+		timeRemap.copyConfigurationFrom(_timeRemap);
 		_timeRemap = timeRemap;
 	}
 
@@ -280,72 +291,66 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		}
 	}
 
-	private void setMediaTime(RenderContext context, MediaInput input) {
+	private Time calcVideoMediaTime(MediaInput input) {
 		Time time;
 
 		if (LayerNature.isTimeRemapEnabled(this)) {
-			if (context == _vrContext) {
-				Time frameDuration = input.getVideoFrameDuration();
-				int timeScale = frameDuration.timeScale;
+			double t0 = _timeRemap.value(_vrContext);
 
-				double t0 = _timeRemap.value(context);
-				double t1 = _timeRemap.valueAtTime(context.getTime().add(frameDuration), context);
-																	// TODO ↑ t1はコンポジションのframeDurationで計算すべきかも。
+			Time ctxTime = _vrContext.getTime();
+			double t1 = _timeRemap.valueAtTime(new Time(ctxTime.timeValue + 1, ctxTime.timeScale), _vrContext);
 
-				time = new Time(Math.round(t0 * timeScale), timeScale);
+			Time frameDuration = input.getVideoFrameDuration();
+			int timeScale = frameDuration.timeScale;
 
-				if (t0 > t1) {
-					time = time.subtract(frameDuration);
-				}
+			time = new Time(Math.round(t0 * timeScale), timeScale);
 
-			} else if (context == _arContext) {
-				int timeScale = _arContext.getAudioMode().sampleRate;
-				time = new Time(Math.round(_timeRemap.value(context) * timeScale), timeScale);
-
-				// TODO 変化量が負の時、オーディオは MediaInput のサンプルレートにおける１フレーム分をずらす必要がある。
-				//      しかし、再生速度を変更している場合のオーディオの処理は今のところデタラメなので保留。
-
-			} else {
-				throw new IllegalArgumentException();
+			// 変化量が負の時のときは１フレーム分ずらす。
+			if (t0 > t1) {
+				time = time.subtract(frameDuration);
 			}
 
 		} else {
-			time = context.getTime().subtract(getStartTime());
+			time = _vrContext.getTime().subtract(getStartTime());
 
 			double rate = getRate();
 			if (rate != 1.0) {
 				time = new Time(Math.round(time.timeValue * rate), time.timeScale);
 
 				if (rate < 0.0) {
-					time = time.add(input.getDuration());
+					Time duration = input.getDuration();
+					if (duration != null) {
+						time = time.add(duration);
 
-					// 逆再生時は１フレーム分ずらす
-					if (context == _vrContext) {
+						// 逆再生時は１フレーム分ずらす。
 						Time frameDuration = input.getVideoFrameDuration();
 						time = time.subtract(frameDuration);
 
-					} else if (context == _arContext) {
-						// TODO オーディオの場合、MediaInput のサンプルレートにおける１フレーム分をずらす必要がある。
-						//      しかし、再生速度を変更している場合のオーディオの処理は今のところデタラメなので保留。
-
 					} else {
-						throw new IllegalArgumentException();
+						duration = getOutPoint().subtract(getStartTime());
+						time = time.add(duration);
 					}
 				}
 			}
 		}
 
-		context.setTime(time);
+		return time;
 	}
 
 	private void setupVideoRendererNormal(
 			VideoLayerComposer composer, final Camera camera, final CollapseTransformation ct) {
 
 		final MediaInput input = getMediaInput();
-		RenderResolution resolution = _vrContext.getRenderResolution();
+		final RenderResolution resolution = _vrContext.getRenderResolution();
+
+		WrappedOperation<VideoBounds> inputBoundsOperation = new WrappedOperation<VideoBounds>() {
+			public VideoBounds execute() {
+				return resolution.scale(input.getVideoFrameBounds());
+			}
+		};
 
 		VideoBounds bounds = _vePipeline.getVideoBounds(
-				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), resolution.scale(input.getVideoFrameBounds()));
+				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBoundsOperation);
 		Vec2d offset = new Vec2d(-bounds.x/resolution.scale, -bounds.y/resolution.scale);
 
 		final double[] mvMatrix = new double[16];
@@ -363,15 +368,14 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			public VideoLayerBuffer render(boolean withDepthBuffer) {
 				VideoBuffer effectedBuffer = null;
 				try {
-					VideoBuffer inputBuffer = _vrContext.saveAndExecute(new WrappedOperation<VideoBuffer>() {
+					WrappedOperation<VideoBuffer> inputBufferOperation = new WrappedOperation<VideoBuffer>() {
 						public VideoBuffer execute() {
-							setMediaTime(_vrContext, input);
-							return input.getVideoFrameImage();
+							return input.getVideoFrameImage(calcVideoMediaTime(input));
 						}
-					});
+					};
 
 					effectedBuffer = _vePipeline.doVideoEffects(
-							_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBuffer);
+							_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputBufferOperation);
 
 					VideoBuffer trnsfrmdBuffer = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), camera.getViewportSize());
 					trnsfrmdBuffer.allocateAsTexture();
@@ -443,7 +447,7 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 
 				_vrContext.saveAndExecute(new WrappedOperation<Object>() {
 					public Object execute() {
-						setMediaTime(_vrContext, input);
+						_vrContext.setTime(calcVideoMediaTime(input));
 						input.rasterize(rasterBuffer, depthBuffer, mvMatrix, prjMatrix);
 						return null;
 					}
@@ -500,6 +504,173 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 		_vrSupport.pushMatrixAndExecute(operation);
 	}
 
+	private AudioBuffer getTimeRemappedAudioChunk(MediaInput input) {
+		AudioBuffer ab1 = null;
+		AudioBuffer ab2 = null;
+		IObjectArray<Double> times = null;
+
+		try {
+			AudioMode audioMode = _arContext.getAudioMode();
+			int sampleRate = audioMode.sampleRate;
+
+			ab1 = _arSupport.createAudioBuffer();
+
+			times = _arrayPools.getObjectArray(ab1.getFrameCount());
+			_timeRemap.values(times, audioMode.sampleDuration, _arContext.getEvaluationResolution(), _arContext);
+
+
+			// 音声データを取得する範囲を求める。
+			double min = Double.POSITIVE_INFINITY, max = Double.NEGATIVE_INFINITY;
+			Object[] timeArray = times.getArray();
+			for (int i = 0, n = times.getLength(); i < n; ++i) {
+				min = Math.min(min, (Double) timeArray[i]);
+				max = Math.max(max, (Double) timeArray[i]);
+			}
+			long timeValueMin = (long) Math.floor(min*sampleRate);
+			long timeValueMax = (long) Math.ceil(max*sampleRate);
+
+
+			// 上で求めた範囲の音声データをMediaInputから取得。
+			_arContext.setFrameCount((int)(timeValueMax - timeValueMin) + 1);
+
+			ab2 = input.getAudioChunk(new Time(timeValueMin, sampleRate));
+			if (ab2 == null) return null;
+
+
+			// タイムリマップの計算値に従ってリサンプルする。
+			Object data1 = ab1.getData();
+			Object data2 = ab2.getData();
+			int n1 = ab1.getFrameCount();
+
+			switch (audioMode.dataType) {
+				case SHORT: {
+					short[] array1 = (short[]) data1, array2 = (short[]) data2;
+					for (int i = 0; i < n1; ++i) {
+						int j = (int)(Math.round((Double)timeArray[i]*sampleRate) - timeValueMin);
+						array1[i*2  ] = array2[j*2  ];
+						array1[i*2+1] = array2[j*2+1];
+					}
+					break;
+				}
+				case INT: {
+					int[] array1 = (int[]) data1, array2 = (int[]) data2;
+					for (int i = 0; i < n1; ++i) {
+						int j = (int)(Math.round((Double)timeArray[i]*sampleRate) - timeValueMin);
+						array1[i*2  ] = array2[j*2  ];
+						array1[i*2+1] = array2[j*2+1];
+					}
+					break;
+				}
+				case FLOAT: {
+					float[] array1 = (float[]) data1, array2 = (float[]) data2;
+					for (int i = 0; i < n1; ++i) {
+						int j = (int)(Math.round((Double)timeArray[i]*sampleRate) - timeValueMin);
+						array1[i*2  ] = array2[j*2  ];
+						array1[i*2+1] = array2[j*2+1];
+					}
+					break;
+				}
+				default:
+					throw new UnsupportedOperationException(
+							"unsupported AudioMode.DataType: " + audioMode.dataType);
+			}
+
+
+			AudioBuffer result = ab1;
+			ab1 = null;
+			return result;
+
+		} finally {
+			if (ab1 != null) ab1.dispose();
+			if (ab2 != null) ab2.dispose();
+			if (times != null) times.release();
+		}
+	}
+
+	private AudioBuffer getRateChangedAudioChunk(MediaInput input, Time time, double rate) {
+		AudioBuffer ab1 = null;
+		AudioBuffer ab2 = null;
+
+		try {
+			AudioMode audioMode = _arContext.getAudioMode();
+			int sampleRate = audioMode.sampleRate;
+
+			ab1 = _arSupport.createAudioBuffer();
+
+			long timeValueMin;
+			long timeValueMax;
+			double duration = input.getDuration().toSecond();
+
+			if (rate >= 0) {
+				timeValueMin = (long) Math.floor(time.toSecond() * sampleRate * rate);
+
+				Time t = time.add(new Time(_arContext.getFrameCount(), sampleRate));
+				timeValueMax = (long) Math.ceil(t.toSecond() * sampleRate * rate);
+
+			} else {
+				timeValueMax =  (long) Math.ceil(duration * sampleRate + time.toSecond() * sampleRate * rate);
+
+				Time t = time.add(new Time(_arContext.getFrameCount(), sampleRate));
+				timeValueMin = (long) Math.floor(duration * sampleRate + t.toSecond() * sampleRate * rate);
+			}
+
+			_arContext.setFrameCount((int)(timeValueMax - timeValueMin) + 1);
+
+			ab2 = input.getAudioChunk(new Time(timeValueMin, sampleRate));
+			if (ab2 == null) return null;
+
+
+			Object data1 = ab1.getData();
+			Object data2 = ab2.getData();
+			int n1 = ab1.getFrameCount();
+
+			switch (audioMode.dataType) {
+				case SHORT: {
+					short[] array1 = (short[]) data1, array2 = (short[]) data2;
+					for (int i = 0; i < n1; ++i) {
+						int j = (rate >= 0) ? (int)(Math.round((time.toSecond() * sampleRate + i) * rate) - timeValueMin)
+											: (int)(Math.round(duration * sampleRate + (time.toSecond() * sampleRate + i) * rate) - timeValueMin); 
+						array1[i*2  ] = array2[j*2  ];
+						array1[i*2+1] = array2[j*2+1];
+					}
+					break;
+				}
+				case INT: {
+					int[] array1 = (int[]) data1, array2 = (int[]) data2;
+					for (int i = 0; i < n1; ++i) {
+						int j = (rate >= 0) ? (int)(Math.round((time.toSecond() * sampleRate + i) * rate) - timeValueMin)
+											: (int)(Math.round(duration * sampleRate + (time.toSecond() * sampleRate + i) * rate) - timeValueMin); 
+						array1[i*2  ] = array2[j*2  ];
+						array1[i*2+1] = array2[j*2+1];
+					}
+					break;
+				}
+				case FLOAT: {
+					float[] array1 = (float[]) data1, array2 = (float[]) data2;
+					for (int i = 0; i < n1; ++i) {
+						int j = (rate >= 0) ? (int)(Math.round((time.toSecond() * sampleRate + i) * rate) - timeValueMin)
+											: (int)(Math.round(duration * sampleRate + (time.toSecond() * sampleRate + i) * rate) - timeValueMin); 
+						array1[i*2  ] = array2[j*2  ];
+						array1[i*2+1] = array2[j*2+1];
+					}
+					break;
+				}
+				default:
+					throw new UnsupportedOperationException(
+							"unsupported AudioMode.DataType: " + audioMode.dataType);
+			}
+
+
+			AudioBuffer result = ab1;
+			ab1 = null;
+			return result;
+
+		} finally {
+			if (ab1 != null) ab1.dispose();
+			if (ab2 != null) ab2.dispose();
+		}
+	}
+
 	public AudioBuffer renderAudioChunk() {
 		if (!LayerNature.isAudioEnabled(this)) {
 			return null;
@@ -510,25 +681,51 @@ public abstract class AbstractMediaLayer extends AbstractTransformableLayer impl
 			return null;
 		}
 
-		AudioBuffer ab = _arContext.saveAndExecute(new WrappedOperation<AudioBuffer>() {
+		WrappedOperation<AudioBuffer> inputOperation = new WrappedOperation<AudioBuffer>() {
 			public AudioBuffer execute() {
-				setMediaTime(_arContext, input);
-				return input.getAudioChunk();
-			}
-		});
+				if (LayerNature.isTimeRemapEnabled(AbstractMediaLayer.this)) {
+					return getTimeRemappedAudioChunk(input);
 
-		if (ab == null) {
-			return null;
+				} else {
+					Time time = _arContext.getTime().subtract(getStartTime());
+					double rate = getRate();
+					if (rate == 1.0) {
+						return input.getAudioChunk(time);
+					} else {
+						return getRateChangedAudioChunk(input, time, rate);
+					}
+				}
+			}
+		};
+
+		AudioBuffer ab = _aePipeline.doAudioEffects(
+				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), inputOperation);
+
+		if (_audioLevels.hasKeyframe() || _audioLevels.getExpression() != null
+				|| !_audioLevels.getStaticValue().equals(Vec2d.ZERO)) {
+
+			IObjectArray<Vec2d> audioLevels = _arrayPools.getObjectArray(ab.getFrameCount());
+
+			_audioLevels.values(audioLevels, ab.getAudioMode().sampleDuration,
+								_arContext.getEvaluationResolution(), _arContext);
+			_arSupport.amplify(ab, audioLevels);
+
+			audioLevels.release();
 		}
 
-		ab = _aePipeline.doAudioEffects(
-				_effectsEnabled ? _effects : Collections.<Effect>emptyList(), ab);
+		// インポイントよりも手前とアウトポイント以降はゼロクリアする
+		Time time = _arContext.getTime();
+		Time sampleDuration = _arContext.getAudioMode().sampleDuration;
 
-		// TODO オーディオレベルをアニメートしている場合、サンプル毎にオーディオレベルの値は異なるため、
-		//      バッファ全体を同じオーディオレベルで処理するのは正しくない。
-		Vec2d audioLevels = _audioLevels.value(_arContext);
-		if (audioLevels.x != 0 || audioLevels.y != 0) {
-			_arSupport.amplify(ab, audioLevels);
+		int clearFrameCount = (int) getInPoint().subtract(time).toFrameNumber(sampleDuration);
+		if (clearFrameCount > 0) {
+			_arSupport.clear(ab, 0, clearFrameCount);
+		}
+
+		int clearFrameOffset = (int) getOutPoint().subtract(time).toFrameNumber(sampleDuration);
+		clearFrameCount = _arContext.getFrameCount() - clearFrameOffset;
+		if (clearFrameCount > 0) {
+			_arSupport.clear(ab, clearFrameOffset, clearFrameCount);
 		}
 
 		return ab;
