@@ -140,9 +140,10 @@ public class CompositionItemImpl extends AbstractItem implements CompositionItem
 			return new VideoBounds(size.width, size.height);  // TODO 毎回newするのは無駄
 		}
 
-		public VideoBuffer getVideoFrameImage() {
+		public VideoBuffer getVideoFrameImage(final Time mediaTime) {
 			VideoBuffer vb = _vrContext.saveAndExecute(new WrappedOperation<VideoBuffer>() {
 				public VideoBuffer execute() {
+					_vrContext.setTime(mediaTime);
 					return _composition.renderVideoFrame();
 				}
 			});
@@ -150,9 +151,10 @@ public class CompositionItemImpl extends AbstractItem implements CompositionItem
 			return vb;
 		}
 
-		public AudioBuffer getAudioChunk() {
+		public AudioBuffer getAudioChunk(final Time mediaTime) {
 			return _arContext.saveAndExecute(new WrappedOperation<AudioBuffer>() {
 				public AudioBuffer execute() {
+					_arContext.setTime(mediaTime);
 					return _composition.renderAudioChunk();
 				}
 			});
