@@ -27,6 +27,7 @@ import java.io.File;
 import java.io.IOException;
 import java.nio.ByteBuffer;
 import java.nio.ByteOrder;
+import java.util.Arrays;
 
 import javax.sound.sampled.AudioFormat;
 import javax.sound.sampled.AudioInputStream;
@@ -37,8 +38,10 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import ch.kuramo.javie.api.AudioMode;
+import ch.kuramo.javie.api.IArray;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IArrayPools;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.JavieRuntimeException;
 import ch.kuramo.javie.core.MediaFileInput;
@@ -57,12 +60,11 @@ public class JavaSoundInput implements MediaFileInput {
 
 	private Time _duration;
 
+	private AudioMode _audioMode;
+
 	private AudioInputStream _stream;
 
-	private long _position;
-
-	private byte[] _buffer;
-
+	private long _streamPosition;
 
 	@Inject
 	private AudioRenderContext _arContext;
@@ -70,6 +72,9 @@ public class JavaSoundInput implements MediaFileInput {
 	@Inject
 	private AudioRenderSupport _arSupport;
 
+	@Inject
+	private IArrayPools _arrayPools;
+
 
 	public JavaSoundInput() {
 		super();
@@ -82,7 +87,19 @@ public class JavaSoundInput implements MediaFileInput {
 			AudioInputStream stream = AudioSystem.getAudioInputStream(file);
 			try {
 				long numFrames = stream.getFrameLength();
-				float frameRate = stream.getFormat().getFrameRate();
+				AudioFormat format = stream.getFormat();
+
+				// getFrameLengthはバイト数ではなくフレーム数を返すはずなのに、Macではバイト数を返すバグがあるようである。
+				// getFrameLengthが返した値が正しければ、それにgetFrameSizeの値を掛けてもファイルサイズを超えるはずはないが、
+				// このバグが発生する場合はファイルサイズを超えることになる。以下ではそのチェックと対処をしている。
+				if ((format.getEncoding().equals(AudioFormat.Encoding.PCM_SIGNED)
+						|| format.getEncoding().equals(AudioFormat.Encoding.PCM_UNSIGNED))
+						&& numFrames * format.getFrameSize() > file.length()) {
+
+					numFrames /= format.getFrameSize();
+				}
+
+				float frameRate = format.getFrameRate();
 				int frameRateInt = (int) frameRate;
 				if (frameRate - frameRateInt != 0) {
 					_logger.warn("frame rate is not integer: " + frameRate);
@@ -114,16 +131,21 @@ public class JavaSoundInput implements MediaFileInput {
 			}
 			_stream = null;
 		}
-		_position = 0;
+		_streamPosition = 0;
 	}
 
-	public synchronized AudioBuffer getAudioChunk() {
+	public synchronized AudioBuffer getAudioChunk(Time mediaTime) {
 		try {
-			Time time = _arContext.getTime();
 			AudioMode audioMode = _arContext.getAudioMode();
-			long frameNumber = time.toFrameNumber(audioMode.sampleDuration);
+			long frameNumber = mediaTime.toFrameNumber(audioMode.sampleDuration);
 
-			if (frameNumber < _position) {
+			if (-frameNumber >= _arContext.getFrameCount() || !mediaTime.before(_duration)) {
+				AudioBuffer ab = _arSupport.createAudioBuffer();
+				_arSupport.clear(ab);
+				return ab;
+			}
+
+			if (audioMode != _audioMode || audioMode.frameSize*frameNumber < _streamPosition) {
 				closeStream();
 			}
 
@@ -148,9 +170,9 @@ public class JavaSoundInput implements MediaFileInput {
 		// 変換の必要が無い場合、AudioSystem.getAudioInputStream は元のストリームをそのまま返すようなので
 		// 以下のように無条件に変換を試みても無駄な変換は発生しないようである。
 
-		AudioMode audioMode = _arContext.getAudioMode();
-		int bits = audioMode.sampleSize * 8;
-		int ch = audioMode.channels;
+		_audioMode = _arContext.getAudioMode();
+		int bits = _audioMode.sampleSize * 8;
+		int ch = _audioMode.channels;
 		boolean bigEndian = ByteOrder.nativeOrder().equals(ByteOrder.BIG_ENDIAN);
 
 		AudioInputStream s1 = AudioSystem.getAudioInputStream(_file);
@@ -160,7 +182,7 @@ public class JavaSoundInput implements MediaFileInput {
 		AudioInputStream s2 = AudioSystem.getAudioInputStream(f2, s1);
 
 		// サンプルレートを変換
-		AudioFormat f3 = new AudioFormat(audioMode.sampleRate, bits, ch, true, bigEndian);
+		AudioFormat f3 = new AudioFormat(_audioMode.sampleRate, bits, ch, true, bigEndian);
 		return AudioSystem.getAudioInputStream(f3, s2);
 	}
 
@@ -168,42 +190,69 @@ public class JavaSoundInput implements MediaFileInput {
 		AudioBuffer ab = _arSupport.createAudioBuffer();
 		AudioMode audioMode = ab.getAudioMode();
 		Object data = ab.getData();
+		int dataOffset = 0;
 		int dataLength = ab.getDataLength();
 		int lengthInBytes = ab.getDataLengthInBytes();
 
-		// TODO ストリームの末尾を超えてスキップしようとすると例外発生する？
-		_stream.skip(audioMode.frameSize * (frameNumber - _position));
+		if (frameNumber >= 0) {
+			long skip = audioMode.frameSize*frameNumber - _streamPosition;
+			if (_stream.skip(skip) != skip) {
+				_logger.warn(String.format("skip failed: frameNumber=%d, skip=%d", frameNumber, skip));
+				closeStream();
+				_arSupport.clear(ab);
+				return ab;
+			}
+			_streamPosition += skip;
+		} else if (_streamPosition == 0) {
+			_arSupport.clear(ab, 0, (int)-frameNumber);
+			dataOffset = (int)-frameNumber * audioMode.channels;
+			dataLength -= dataOffset;
+			lengthInBytes -= dataOffset * audioMode.sampleSize;
 
-		if (_buffer == null || _buffer.length < lengthInBytes) {
-			_buffer = new byte[lengthInBytes];
+		} else {
+			throw new IllegalStateException();
 		}
 
-		_stream.read(_buffer, 0, lengthInBytes);
+		IArray<byte[]> array = _arrayPools.getByteArray(lengthInBytes);
+		try {
+			byte[] buffer = array.getArray();
 
-		switch (audioMode.dataType) {
-			case SHORT:
-				ByteBuffer.wrap(_buffer, 0, lengthInBytes).order(ByteOrder.nativeOrder())
-						.asShortBuffer().get((short[]) data, 0, dataLength);
-				break;
-			case INT:
-				ByteBuffer.wrap(_buffer, 0, lengthInBytes).order(ByteOrder.nativeOrder())
-						.asIntBuffer().get((int[]) data, 0, dataLength);
-				break;
-			case FLOAT:
-				for (int i = 0; i < dataLength; ++i) {
-					int value =  (_buffer[i*4  ] & 0xff)
-							  | ((_buffer[i*4+1] & 0xff) <<  8)
-							  | ((_buffer[i*4+2] & 0xff) << 16)
-							  | ((_buffer[i*4+3] & 0xff) << 24);
-					((float[]) data)[i] = (float) value / Integer.MAX_VALUE;
+			int readBytes = 0;
+			do {
+				int n = _stream.read(buffer, readBytes, lengthInBytes - readBytes);
+				if (n == -1) {
+					Arrays.fill(buffer, readBytes, lengthInBytes, (byte)0);
+					break;
 				}
-				break;
-			default:
-				throw new UnsupportedOperationException(
-						"unsupported AudioMode.DataType: " + audioMode.dataType);
-		}
+				readBytes += n;
+				_streamPosition += n;
+			} while (readBytes < lengthInBytes);
 
-		_position = frameNumber + ab.getFrameCount();
+			switch (audioMode.dataType) {
+				case SHORT:
+					ByteBuffer.wrap(buffer, 0, lengthInBytes).order(ByteOrder.nativeOrder())
+							.asShortBuffer().get((short[]) data, dataOffset, dataLength);
+					break;
+				case INT:
+					ByteBuffer.wrap(buffer, 0, lengthInBytes).order(ByteOrder.nativeOrder())
+							.asIntBuffer().get((int[]) data, dataOffset, dataLength);
+					break;
+				case FLOAT:
+					for (int i = dataOffset; i < dataLength; ++i) {
+						int value =  (buffer[i*4  ] & 0xff)
+								  | ((buffer[i*4+1] & 0xff) <<  8)
+								  | ((buffer[i*4+2] & 0xff) << 16)
+								  | ((buffer[i*4+3] & 0xff) << 24);
+						((float[]) data)[i] = (float) value / Integer.MAX_VALUE;
+					}
+					break;
+				default:
+					throw new UnsupportedOperationException(
+							"unsupported AudioMode.DataType: " + audioMode.dataType);
+			}
+		} finally {
+			array.release();
+		}
 
 		return ab;
 	}
@@ -228,7 +277,7 @@ public class JavaSoundInput implements MediaFileInput {
 		throw new UnsupportedOperationException("video is not available");
 	}
 
-	public VideoBuffer getVideoFrameImage() {
+	public VideoBuffer getVideoFrameImage(Time mediaTime) {
 		throw new UnsupportedOperationException("video is not available");
 	}
 
