@@ -290,13 +290,15 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 	public AudioBuffer renderAudioChunk() {
 		AudioBuffer ab = null;
 		Time time = _arContext.getTime();
+		Time chunkDuration = Time.fromFrameNumber(
+				_arContext.getFrameCount(), _arContext.getAudioMode().sampleDuration);
 
 		for (Layer layer : _layers) {
 			if (!LayerNature.isAudioEnabled(layer)) {
 				continue;
 			}
 
-			if (layer.getInPoint().after(time) || !layer.getOutPoint().after(time)) {
+			if (layer.getInPoint().after(time.add(chunkDuration)) || !layer.getOutPoint().after(time)) {
 				continue;
 			}
 
