@@ -38,7 +38,6 @@ import ch.kuramo.javie.api.AudioMode.DataType;
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.MediaFileInput;
 import ch.kuramo.javie.core.VideoBuffer;
-import ch.kuramo.javie.core.services.AudioRenderContext;
 import ch.kuramo.javie.core.services.AudioRenderSupport;
 import ch.kuramo.javie.core.services.GLGlobal;
 import ch.kuramo.javie.core.services.SynchronousTaskThread;
@@ -85,9 +84,6 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 	@Inject
 	private VideoRenderSupport _vrSupport;
 
-	@Inject
-	private AudioRenderContext _arContext;
-
 	@Inject
 	private AudioRenderSupport _arSupport;
 
@@ -224,7 +220,7 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 		return _bounds;
 	}
 
-	public VideoBuffer getVideoFrameImage() {
+	public VideoBuffer getVideoFrameImage(Time mediaTime) {
 		if (_videoInput == 0) {
 			return null;
 		}
@@ -233,11 +229,16 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 		VideoBuffer vb = _vrSupport.createVideoBuffer(_vrContext.getColorMode(), bounds);
 		vb.allocateAsTexture();
 
+		if (mediaTime.timeValue < 0 || !mediaTime.before(_duration)) {
+			_vrSupport.clear(vb);
+			return vb;
+		}
+
 		// フレームの開始時刻ちょうどで切り出そうとすると、ひとつ前のフレームが切り出されてしまうことがある。
 		// FPSが30000/1001などに正確に一致していない動画で起きるのか、QuickTime内の処理の誤差かどちらかと思われるが、
 		// いずれにしろフレームの開始時刻ちょうどから0.5フレーム分を加えた時刻で切り出せば回避できるはず。
 		// TODO この方法はQuartz Composerのファイルのようなフレーム単位ではない動画には適用すべきでない。
-		Time time = Time.fromFrameNumber(_vrContext.getTime().toFrameNumber(_videoFrameDuration), _videoFrameDuration);
+		Time time = Time.fromFrameNumber(mediaTime.toFrameNumber(_videoFrameDuration), _videoFrameDuration);
 		final long timeValue = time.timeValue + _videoFrameDuration.timeValue/2;
 		final int timeScale = time.timeScale;
 
@@ -261,17 +262,33 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 		}
 	}
 
-	public AudioBuffer getAudioChunk() {
+	public AudioBuffer getAudioChunk(Time mediaTime) {
 		if (_audioInput == 0) {
 			return null;
 		}
 
-		final Time time = _arContext.getTime();
 		final AudioBuffer ab = _arSupport.createAudioBuffer();
+		final AudioMode am = ab.getAudioMode();
+
+		long fn = mediaTime.toFrameNumber(am.sampleDuration);
+		if (-fn >= ab.getFrameCount() || !mediaTime.before(_duration)) {
+			_arSupport.clear(ab);
+			return ab;
+		}
+
+		final long frameNumber;
+		final int offset;
+		if (fn >= 0) {
+			frameNumber = fn;
+			offset = 0;
+		} else {
+			frameNumber = 0;
+			offset = (int) -fn;
+			_arSupport.clear(ab, 0, offset);
+		}
 
 		int error = _audioThread.invoke(new Task<Integer>() {
 			public Integer run() throws Exception {
-				AudioMode am = ab.getAudioMode();
 				if (am != _audioMode) {
 					int error = setAudioDescription(
 							_audioInput, am.channels, am.sampleRate, am.sampleSize,
@@ -284,7 +301,7 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 				}
 
 				int error = audioChunkFromTime(
-						_audioInput, time.timeValue, time.timeScale, ab.getData(), ab.getFrameCount());
+						_audioInput, frameNumber, am.sampleRate, ab.getData(), offset, ab.getFrameCount() - offset);
 				if (error != 0) {
 					_logger.error("audioChunkFromTime: error " + error);
 				}
@@ -318,6 +335,6 @@ public class MacOSXQTCoreVideoInput implements MediaFileInput {
 			long audioInput, int channels, int sampleRate, int sampleSize, boolean floatingPoint);
 
 	private native int audioChunkFromTime(
-			long audioInput, long timeValue, int timeScale, Object buffer, int frameCount);
+			long audioInput, long timeValue, int timeScale, Object buffer, int offset, int frameCount);
 
 }
