@@ -136,7 +136,10 @@ public class MediaItemLayerImpl extends AbstractMediaLayer implements MediaItemL
 
 		LayerComposition preComp = getPrecomposition();
 		if (preComp != null) {
-			preComp.prepareExpression(scope.createPrecompositionScope());
+			ExpressionScope preCompScope = scope.createPrecompositionScope(preComp);
+			if (preCompScope != null) {
+				preComp.prepareExpression(preCompScope);
+			}
 		}
 	}
 
