@@ -133,7 +133,7 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 			return _bounds;
 		}
 
-		public VideoBuffer getVideoFrameImage() {
+		public VideoBuffer getVideoFrameImage(Time mediaTime) {
 			ColorMode colorMode = _vrContext.getColorMode();
 			Size2i size = _vrContext.getRenderResolution().scale(_size);
 
@@ -154,7 +154,7 @@ public class SolidColorItemImpl extends AbstractItem implements SolidColorItem {
 			_vrSupport.fillRectCR(resultBuffer, depthBuffer, mvMatrix, prjMatrix, size, _color);
 		}
 
-		public AudioBuffer getAudioChunk() {
+		public AudioBuffer getAudioChunk(Time mediaTime) {
 			throw new UnsupportedOperationException("audio is not available");
 		}
 
