@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,15 +27,16 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import ch.kuramo.javie.api.ColorMode;
+import ch.kuramo.javie.api.IArray;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.VideoBounds;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
 import ch.kuramo.javie.core.VideoBuffer;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 
 import com.google.inject.Inject;
 
-public class VideoBufferImpl implements VideoBuffer, PIVideoBuffer {
+public class VideoBufferImpl implements VideoBuffer, IVideoBuffer {
 
 	private static final Logger _logger = LoggerFactory.getLogger(VideoBufferImpl.class);
 
@@ -50,7 +51,7 @@ public class VideoBufferImpl implements VideoBuffer, PIVideoBuffer {
 
 	private int _texture;
 
-	private Object _array;
+	private IArray<?> _array;
 
 
 	public VideoBufferImpl(ColorMode colorMode, Size2i imageSize) {
@@ -75,7 +76,7 @@ public class VideoBufferImpl implements VideoBuffer, PIVideoBuffer {
 			_logger.warn("finalizing a VideoBufferImpl object, but the object is not disposed.");
 
 			if (_array != null) {
-				_vrSupport.releaseArray(_array);
+				_array.release();
 				_array = null;
 			}
 		}
@@ -90,7 +91,7 @@ public class VideoBufferImpl implements VideoBuffer, PIVideoBuffer {
 		}
 
 		if (_array != null) {
-			_vrSupport.releaseArray(_array);
+			_array.release();
 			_array = null;
 		}
 	}
@@ -142,8 +143,8 @@ public class VideoBufferImpl implements VideoBuffer, PIVideoBuffer {
 
 		// 配列にデータがある場合、テクスチャにコピーして配列を解放する。
 		if (_array != null) {
-			_vrSupport.copyArrayToTexture(_array, _texture, _colorMode, _imageSize);
-			_vrSupport.releaseArray(_array);
+			_vrSupport.copyArrayToTexture(_array.getArray(), _texture, _colorMode, _imageSize);
+			_array.release();
 			_array = null;
 		}
 
@@ -161,12 +162,12 @@ public class VideoBufferImpl implements VideoBuffer, PIVideoBuffer {
 
 		// テクスチャにデータがある場合、配列にコピーしてテクスチャを破棄する
 		if (_texture != 0) {
-			_vrSupport.copyTextureToArray(_texture, _array, _colorMode, _imageSize);
+			_vrSupport.copyTextureToArray(_texture, _array.getArray(), _colorMode, _imageSize);
 			_vrSupport.deleteTexture(_texture);
 			_texture = 0;
 		}
 
-		return _array;
+		return _array.getArray();
 	}
 
 	public ColorMode getColorMode() {
