@@ -37,17 +37,17 @@ import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 
 import ch.kuramo.javie.api.Color;
+import ch.kuramo.javie.api.IAnimatableBoolean;
+import ch.kuramo.javie.api.IAnimatableColor;
+import ch.kuramo.javie.api.IAnimatableDouble;
+import ch.kuramo.javie.api.IAnimatableEnum;
+import ch.kuramo.javie.api.IAnimatableInteger;
+import ch.kuramo.javie.api.IAnimatableString;
+import ch.kuramo.javie.api.IAnimatableVec2d;
+import ch.kuramo.javie.api.IAnimatableVec3d;
 import ch.kuramo.javie.api.Vec2d;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.api.annotations.Property;
-import ch.kuramo.javie.api.plugin.PIAnimatableBoolean;
-import ch.kuramo.javie.api.plugin.PIAnimatableColor;
-import ch.kuramo.javie.api.plugin.PIAnimatableDouble;
-import ch.kuramo.javie.api.plugin.PIAnimatableEnum;
-import ch.kuramo.javie.api.plugin.PIAnimatableInteger;
-import ch.kuramo.javie.api.plugin.PIAnimatableString;
-import ch.kuramo.javie.api.plugin.PIAnimatableVec2d;
-import ch.kuramo.javie.api.plugin.PIAnimatableVec3d;
 import ch.kuramo.javie.core.AnimatableBoolean;
 import ch.kuramo.javie.core.AnimatableColor;
 import ch.kuramo.javie.core.AnimatableDouble;
@@ -114,6 +114,11 @@ class EffectDescriptorImpl implements EffectDescriptor {
 	}
 
 	private String getString(String key) {
+		String str = getString(key, null);
+		return (str != null) ? str : ('!' + key + '!');
+	}
+
+	private String getString(String key, String defaultStr) {
 		String str = null;
 		if (_bundle != null) {
 			try {
@@ -122,10 +127,7 @@ class EffectDescriptorImpl implements EffectDescriptor {
 				// ignore
 			}
 		}
-		if (str == null) {
-			str = '!' + key + '!';
-		}
-		return str;
+		return (str != null) ? str : defaultStr;
 	}
 
 	private Map<String, PropertyDescriptor> createPropertyDescriptors() {
@@ -138,34 +140,35 @@ class EffectDescriptorImpl implements EffectDescriptor {
 			}
 
 			String name = f.getName();
-			String label = getString(name + ".label");
 			String value = anno.value();
+			String min = anno.min();
+			String max = anno.max();
 
 			Class<?> type = f.getType();
-			if (PIAnimatableDouble.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableDoublePropertyDescriptor(name, label, value));
-			} else if (PIAnimatableInteger.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableIntegerPropertyDescriptor(name, label, value));
-			} else if (PIAnimatableVec2d.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableVec2dPropertyDescriptor(name, label, value));
-			} else if (PIAnimatableVec3d.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableVec3dPropertyDescriptor(name, label, value));
-			} else if (PIAnimatableColor.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableColorPropertyDescriptor(name, label, value));
-			} else if (PIAnimatableString.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableStringPropertyDescriptor(name, label, value));
-			} else if (PIAnimatableBoolean.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableBooleanPropertyDescriptor(name, label, value));
-			} else if (PIAnimatableEnum.class.isAssignableFrom(type)) {
-				map.put(name, new AnimatableEnumPropertyDescriptor(name, label, value));
-			} else if (String.class.equals(type)) {
-				map.put(name, new StringPropertyDescriptor(name, label, value));
-			} else if (Enum.class.isAssignableFrom(type)) {
-				@SuppressWarnings("unchecked")
-				Class<Enum> enumType = (Class<Enum>) type;
-				map.put(name, new EnumPropertyDescriptor(name, label, value, enumType));
-			} else if (type.isPrimitive()) {
-				map.put(name, new PrimitivePropertyDescriptor(name, label, value, type));
+			if (IAnimatableDouble.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableDoublePropertyDescriptor(name, value, min, max));
+			} else if (IAnimatableInteger.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableIntegerPropertyDescriptor(name, value, min, max));
+			} else if (IAnimatableVec2d.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableVec2dPropertyDescriptor(name, value, min, max));
+			} else if (IAnimatableVec3d.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableVec3dPropertyDescriptor(name, value, min, max));
+			} else if (IAnimatableColor.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableColorPropertyDescriptor(name, value));
+			} else if (IAnimatableString.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableStringPropertyDescriptor(name, value));
+			} else if (IAnimatableBoolean.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableBooleanPropertyDescriptor(name, value));
+			} else if (IAnimatableEnum.class.isAssignableFrom(type)) {
+				map.put(name, new AnimatableEnumPropertyDescriptor(name, value));
+//			} else if (String.class.equals(type)) {
+//				map.put(name, new StringPropertyDescriptor(name, value));
+//			} else if (Enum.class.isAssignableFrom(type)) {
+//				@SuppressWarnings("unchecked")
+//				Class<Enum> enumType = (Class<Enum>) type;
+//				map.put(name, new EnumPropertyDescriptor(name, value, enumType));
+//			} else if (type.isPrimitive()) {
+//				map.put(name, new PrimitivePropertyDescriptor(name, value, type));
 			} else {
 				// 非サポートの型
 				// EffectRegistryImpl#processProperties で警告を出しているはずなので無視
@@ -227,11 +230,11 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		protected final Method setter;
 
-		private AbstractPropertyDescriptor(Class<T> type, String name, String label) {
+		private AbstractPropertyDescriptor(Class<T> type, String name) {
 			super();
 			this.type = type;
 			this.name = name;
-			this.label = label;
+			this.label = EffectDescriptorImpl.this.getString(name + ".label");
 			try {
 				String upperCamelCase = Character.toUpperCase(name.charAt(0)) + name.substring(1);
 				getter = _exteriorClass.getDeclaredMethod("get" + upperCamelCase);
@@ -253,6 +256,10 @@ class EffectDescriptorImpl implements EffectDescriptor {
 			return label;
 		}
 
+		public String getString(String key) {
+			return EffectDescriptorImpl.this.getString(name + "." + key, null);
+		}
+
 		public void afterDecode(Project p, Effect effect) throws ProjectDecodeException {
 			// nothing to do
 		}
@@ -284,13 +291,19 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Double value;
 
-		private AnimatableDoublePropertyDescriptor(String name, String label, String value) {
-			super(AnimatableDouble.class, name, label);
-			this.value = toDouble(value);
+		private final Double min;
+
+		private final Double max;
+
+		private AnimatableDoublePropertyDescriptor(String name, String value, String min, String max) {
+			super(AnimatableDouble.class, name);
+			this.min = toDouble(min, Double.NEGATIVE_INFINITY);
+			this.max = Math.max(this.min, toDouble(max, Double.POSITIVE_INFINITY));
+			this.value = Math.max(this.min, Math.min(this.max, toDouble(value, 0)));
 		}
 
 		public void initValue(Effect effect) {
-			set(effect, new AnimatableDouble(value));
+			set(effect, new AnimatableDouble(value, min, max));
 		}
 	}
 
@@ -298,13 +311,19 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Integer value;
 
-		private AnimatableIntegerPropertyDescriptor(String name, String label, String value) {
-			super(AnimatableInteger.class, name, label);
-			this.value = toInteger(value);
+		private final Integer min;
+
+		private final Integer max;
+
+		private AnimatableIntegerPropertyDescriptor(String name, String value, String min, String max) {
+			super(AnimatableInteger.class, name);
+			this.min = toInteger(min, Integer.MIN_VALUE);
+			this.max = Math.max(this.min, toInteger(max, Integer.MAX_VALUE));
+			this.value = Math.max(this.min, Math.min(this.max, toInteger(value, 0)));
 		}
 
 		public void initValue(Effect effect) {
-			set(effect, new AnimatableInteger(value));
+			set(effect, new AnimatableInteger(value, min, max));
 		}
 	}
 
@@ -312,13 +331,19 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Vec2d value;
 
-		private AnimatableVec2dPropertyDescriptor(String name, String label, String value) {
-			super(AnimatableVec2d.class, name, label);
-			this.value = toVec2d(value);
+		private final Vec2d min;
+
+		private final Vec2d max;
+
+		private AnimatableVec2dPropertyDescriptor(String name, String value, String min, String max) {
+			super(AnimatableVec2d.class, name);
+			this.min = toVec2d(min, Vec2d.NEGATIVE_INFINITY);
+			this.max = Vec2d.max(this.min, toVec2d(max, Vec2d.POSITIVE_INFINITY));
+			this.value = Vec2d.max(this.min, Vec2d.min(this.max, toVec2d(value, Vec2d.ZERO)));
 		}
 
 		public void initValue(Effect effect) {
-			set(effect, new AnimatableVec2d(value));
+			set(effect, new AnimatableVec2d(value, min, max));
 		}
 	}
 
@@ -326,13 +351,19 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Vec3d value;
 
-		private AnimatableVec3dPropertyDescriptor(String name, String label, String value) {
-			super(AnimatableVec3d.class, name, label);
-			this.value = toVec3d(value);
+		private final Vec3d min;
+
+		private final Vec3d max;
+
+		private AnimatableVec3dPropertyDescriptor(String name, String value, String min, String max) {
+			super(AnimatableVec3d.class, name);
+			this.min = toVec3d(min, Vec3d.NEGATIVE_INFINITY);
+			this.max = Vec3d.max(this.min, toVec3d(max, Vec3d.POSITIVE_INFINITY));
+			this.value = Vec3d.max(this.min, Vec3d.min(this.max, toVec3d(value, Vec3d.ZERO)));
 		}
 
 		public void initValue(Effect effect) {
-			set(effect, new AnimatableVec3d(value));
+			set(effect, new AnimatableVec3d(value, min, max));
 		}
 	}
 
@@ -340,9 +371,9 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Color value;
 
-		private AnimatableColorPropertyDescriptor(String name, String label, String value) {
-			super(AnimatableColor.class, name, label);
-			this.value = toColor(value);
+		private AnimatableColorPropertyDescriptor(String name, String value) {
+			super(AnimatableColor.class, name);
+			this.value = toColor(value, Color.BLACK);
 		}
 
 		public void initValue(Effect effect) {
@@ -354,8 +385,8 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final String value;
 
-		private AnimatableStringPropertyDescriptor(String name, String label, String value) {
-			super(AnimatableString.class, name, label);
+		private AnimatableStringPropertyDescriptor(String name, String value) {
+			super(AnimatableString.class, name);
 			this.value = value;
 		}
 
@@ -368,8 +399,8 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Boolean value;
 
-		private AnimatableBooleanPropertyDescriptor(String name, String label, String value) {
-			super(AnimatableBoolean.class, name, label);
+		private AnimatableBooleanPropertyDescriptor(String name, String value) {
+			super(AnimatableBoolean.class, name);
 			this.value = toBoolean(value);
 		}
 
@@ -387,8 +418,8 @@ class EffectDescriptorImpl implements EffectDescriptor {
 
 		private final Enum value;
 
-		private AnimatableEnumPropertyDescriptor(String name, String label, String value) {
-			super(getPropertyType(name), name, label);
+		private AnimatableEnumPropertyDescriptor(String name, String value) {
+			super(getPropertyType(name), name);
 			try {
 				ParameterizedType genericSuper = (ParameterizedType) type.getGenericSuperclass();
 				enumType = (Class<Enum>) genericSuper.getActualTypeArguments()[0];
@@ -412,12 +443,13 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		}
 	}
 
+	@SuppressWarnings("unused")
 	private class StringPropertyDescriptor extends AbstractPropertyDescriptor<String> {
 
 		private final String value;
 
-		private StringPropertyDescriptor(String name, String label, String value) {
-			super(String.class, name, label);
+		private StringPropertyDescriptor(String name, String value) {
+			super(String.class, name);
 			this.value = value;
 		}
 
@@ -426,13 +458,13 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		}
 	}
 
-	@SuppressWarnings("unchecked")
+	@SuppressWarnings({ "unchecked", "unused" })
 	private class EnumPropertyDescriptor extends AbstractPropertyDescriptor<Enum> {
 
 		private final Enum value;
 
-		private EnumPropertyDescriptor(String name, String label, String value, Class<Enum> enumType) {
-			super(enumType, name, label);
+		private EnumPropertyDescriptor(String name, String value, Class<Enum> enumType) {
+			super(enumType, name);
 			this.value = toEnum(enumType, value);
 		}
 
@@ -441,13 +473,13 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		}
 	}
 
-	@SuppressWarnings("unchecked")
+	@SuppressWarnings({ "unchecked", "unused" })
 	private class PrimitivePropertyDescriptor extends AbstractPropertyDescriptor {
 
 		private final Object value;
 
-		private PrimitivePropertyDescriptor(String name, String label, String value, Class<?> primitiveType) {
-			super(primitiveType, name, label);
+		private PrimitivePropertyDescriptor(String name, String value, Class<?> primitiveType) {
+			super(primitiveType, name);
 			this.value = toPrimitive(primitiveType, value);
 		}
 
@@ -456,152 +488,179 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		}
 	}
 
-	private static Boolean toBoolean(String s) {
-		return Boolean.valueOf(s.trim());
+	private static boolean toBoolean(String s) {
+		return Boolean.parseBoolean(s.trim());
 	}
 
-	private static Double toDouble(String s) {
-		try {
-			return Double.valueOf(s.trim());
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Double.valueOf(0);
-		}
-	}
-
-	private static Float toFloat(String s) {
-		try {
-			return Float.valueOf(s.trim());
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Float.valueOf(0);
-		}
-	}
-
-	private static Long toLong(String s) {
-		try {
-			return Long.valueOf(s.trim());
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Long.valueOf(0);
-		}
-	}
-
-	private static Integer toInteger(String s) {
-		try {
-			return Integer.valueOf(s.trim());
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Integer.valueOf(0);
-		}
-	}
-
-	private static Short toShort(String s) {
-		try {
-			return Short.valueOf(s.trim());
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Short.valueOf((short) 0);
-		}
-	}
-
-	private static Character toCharacter(String s) {
-		try {
-			return Character.valueOf((char) Integer.parseInt(s.trim()));
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Character.valueOf((char) 0);
-		}
-	}
-
-	private static Byte toByte(String s) {
-		try {
-			return Byte.valueOf((byte) Integer.parseInt(s.trim()));
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			return Byte.valueOf((byte) 0);
-		}
-	}
-
-	private static Vec2d toVec2d(String s) {
-		double x, y;
-		try {
-			String[] array = s.trim().split("\\s*,\\s*");
-			switch (array.length) {
-				case 1:
-					x = y = Double.valueOf(array[0]);
-					break;
-				default:
-					x = Double.valueOf(array[0]);
-					y = Double.valueOf(array[1]);
-					break;
+	private static double toDouble(String s, double defaultValue) {
+		if (s.length() > 0) {
+			try {
+				return Double.parseDouble(s.trim());
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
 			}
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			x = y = 0;
 		}
-		return new Vec2d(x, y);
+		return defaultValue;
+	}
+
+	private static float toFloat(String s, float defaultValue) {
+		if (s.length() > 0) {
+			try {
+				return Float.parseFloat(s.trim());
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
+	}
+
+	private static long toLong(String s, long defaultValue) {
+		if (s.length() > 0) {
+			try {
+				return Long.parseLong(s.trim());
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
+	}
+
+	private static int toInteger(String s, int defaultValue) {
+		if (s.length() > 0) {
+			try {
+				return Integer.parseInt(s.trim());
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
+	}
+
+	private static short toShort(String s, short defaultValue) {
+		if (s.length() > 0) {
+			try {
+				return Short.parseShort(s.trim());
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
+	}
+
+	private static char toCharacter(String s, char defaultValue) {
+		if (s.length() > 0) {
+			try {
+				int intValue = Integer.parseInt(s.trim());
+				if (intValue < Character.MIN_VALUE || intValue > Character.MAX_VALUE) {
+					throw new NumberFormatException(s);
+				}
+				return (char) intValue;
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
+	}
+
+	private static byte toByte(String s, byte defaultValue) {
+		if (s.length() > 0) {
+			try {
+				int intValue = Integer.parseInt(s.trim());
+				if (intValue < Byte.MIN_VALUE || intValue > Byte.MAX_VALUE) {
+					throw new NumberFormatException(s);
+				}
+				return (byte) intValue;
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
+	}
+
+	private static Vec2d toVec2d(String s, Vec2d defaultValue) {
+		if (s.length() > 0) {
+			try {
+				double x, y;
+				String[] array = s.trim().split("\\s*,\\s*");
+				switch (array.length) {
+					case 1:
+						x = y = Double.parseDouble(array[0]);
+						break;
+					default:
+						x = Double.parseDouble(array[0]);
+						y = Double.parseDouble(array[1]);
+						break;
+				}
+				return new Vec2d(x, y);
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
+			}
+		}
+		return defaultValue;
 	}
 
 
-	private static Vec3d toVec3d(String s) {
-		double x, y, z;
-		try {
-			String[] array = s.trim().split("\\s*,\\s*");
-			switch (array.length) {
-				case 1:
-					x = y = z = Double.valueOf(array[0]);
-					break;
-				case 2:
-					x = Double.valueOf(array[0]);
-					y = Double.valueOf(array[1]);
-					z = 0;
-					break;
-				default:
-					x = Double.valueOf(array[0]);
-					y = Double.valueOf(array[1]);
-					z = Double.valueOf(array[2]);
-					break;
+	private static Vec3d toVec3d(String s, Vec3d defaultValue) {
+		if (s.length() > 0) {
+			try {
+				double x, y, z;
+				String[] array = s.trim().split("\\s*,\\s*");
+				switch (array.length) {
+					case 1:
+						x = y = z = Double.parseDouble(array[0]);
+						break;
+					case 2:
+						x = Double.parseDouble(array[0]);
+						y = Double.parseDouble(array[1]);
+						z = 0;
+						break;
+					default:
+						x = Double.parseDouble(array[0]);
+						y = Double.parseDouble(array[1]);
+						z = Double.parseDouble(array[2]);
+						break;
+				}
+				return new Vec3d(x, y, z);
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
 			}
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			x = y = z = 0;
 		}
-		return new Vec3d(x, y, z);
+		return defaultValue;
 	}
 
-	private static Color toColor(String s) {
-		double r, g, b, a;
-		try {
-			String[] array = s.trim().split("\\s*,\\s*");
-			switch (array.length) {
-				case 1:
-					r = g = b = Double.valueOf(array[0]);
-					a = 1;
-					break;
-				case 2:
-					r = g = b = Double.valueOf(array[0]);
-					a = Double.valueOf(array[1]);
-					break;
-				case 3:
-					r = Double.valueOf(array[0]);
-					g = Double.valueOf(array[1]);
-					b = Double.valueOf(array[2]);
-					a = 1;
-					break;
-				default:
-					r = Double.valueOf(array[0]);
-					g = Double.valueOf(array[1]);
-					b = Double.valueOf(array[2]);
-					a = Double.valueOf(array[3]);
-					break;
+	private static Color toColor(String s, Color defaultValue) {
+		if (s.length() > 0) {
+			try {
+				double r, g, b, a;
+				String[] array = s.trim().split("\\s*,\\s*");
+				switch (array.length) {
+					case 1:
+						r = g = b = Double.parseDouble(array[0]);
+						a = 1;
+						break;
+					case 2:
+						r = g = b = Double.parseDouble(array[0]);
+						a = Double.parseDouble(array[1]);
+						break;
+					case 3:
+						r = Double.parseDouble(array[0]);
+						g = Double.parseDouble(array[1]);
+						b = Double.parseDouble(array[2]);
+						a = 1;
+						break;
+					default:
+						r = Double.parseDouble(array[0]);
+						g = Double.parseDouble(array[1]);
+						b = Double.parseDouble(array[2]);
+						a = Double.parseDouble(array[3]);
+						break;
+				}
+				return new Color(r, g, b, a);
+			} catch (NumberFormatException e) {
+				// TODO ログに警告を出す
 			}
-		} catch (NumberFormatException e) {
-			// TODO ログに警告を出す
-			r = g = b = 0;
-			a = 1;
 		}
-		return new Color(r, g, b, a);
+		return defaultValue;
 	}
 
 	private static <E extends Enum<E>> E toEnum(Class<E> enumType, String s) {
@@ -627,19 +686,19 @@ class EffectDescriptorImpl implements EffectDescriptor {
 		if (primitiveType == boolean.class) {
 			return toBoolean(s);
 		} else if (primitiveType == double.class) {
-			return toDouble(s);
+			return toDouble(s, 0);
 		} else if (primitiveType == float.class) {
-			return toFloat(s);
+			return toFloat(s, 0);
 		} else if (primitiveType == long.class) {
-			return toLong(s);
+			return toLong(s, 0);
 		} else if (primitiveType == int.class) {
-			return toInteger(s);
+			return toInteger(s, 0);
 		} else if (primitiveType == short.class) {
-			return toShort(s);
+			return toShort(s, (short)0);
 		} else if (primitiveType == char.class) {
-			return toCharacter(s);
+			return toCharacter(s, (char)0);
 		} else if (primitiveType == byte.class) {
-			return toByte(s);
+			return toByte(s, (byte)0);
 		} else {
 			throw new JavieRuntimeException("unsupported type: " + primitiveType.getName());
 		}
