@@ -38,9 +38,13 @@ import org.slf4j.LoggerFactory;
 
 import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.ColorMode;
+import ch.kuramo.javie.api.IArray;
+import ch.kuramo.javie.api.IShaderProgram;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.api.VideoBounds;
+import ch.kuramo.javie.api.services.IArrayPools;
+import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.core.BlendMode;
 import ch.kuramo.javie.core.DepthBuffer;
 import ch.kuramo.javie.core.TrackMatte;
@@ -49,10 +53,7 @@ import ch.kuramo.javie.core.VideoLayerBuffer;
 import ch.kuramo.javie.core.WrappedOperation;
 import ch.kuramo.javie.core.internal.DepthBufferImpl;
 import ch.kuramo.javie.core.internal.VideoBufferImpl;
-import ch.kuramo.javie.core.services.ArrayPools;
 import ch.kuramo.javie.core.services.GLGlobal;
-import ch.kuramo.javie.core.services.ShaderProgram;
-import ch.kuramo.javie.core.services.ShaderRegistry;
 import ch.kuramo.javie.core.services.VideoRenderContext;
 import ch.kuramo.javie.core.services.VideoRenderSupport;
 import ch.kuramo.javie.core.shaders.BlendModeShaders;
@@ -81,10 +82,10 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	private VideoRenderContext _vrContext;
 
 	@Inject
-	private ShaderRegistry _shaders;
+	private IShaderRegistry _shaders;
 
 	@Inject
-	private ArrayPools _arrayPools;
+	private IArrayPools _arrayPools;
 
 
 	public VideoBuffer createVideoBuffer(ColorMode colorMode, Size2i size) {
@@ -150,7 +151,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		gl.glDeleteTextures(1, new int[] { texture }, 0);
 	}
 
-	public Object createArray(ColorMode colorMode, Size2i imageSize) {
+	public IArray<?> createArray(ColorMode colorMode, Size2i imageSize) {
 		int arraySize = imageSize.width * imageSize.height * 4;
 
 		switch (colorMode) {
@@ -167,10 +168,6 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		throw new UnsupportedOperationException("ColorMode: " + colorMode.name());
 	}
 
-	public void releaseArray(Object array) {
-		_arrayPools.put(array);
-	}
-
 	public void copyArrayToTexture(Object array, int texture, ColorMode colorMode, Size2i imageSize) {
 		synchronized (_glGlobal.getLockObject()) {
 
@@ -448,7 +445,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 				gl.glActiveTexture(GL.GL_TEXTURE1);
 				gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, matteTexture);
 
-				ShaderProgram program = _shaders.getProgram(TrackMatteShaders.class, trackMatte.name());
+				IShaderProgram program = _shaders.getProgram(TrackMatteShaders.class, trackMatte.name());
 				synchronized (program) {
 					gl.glUseProgram(program.getProgram());
 					gl.glUniform1i(program.getUniformLocation("texFill"), 0);
@@ -508,7 +505,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 				gl.glActiveTexture(GL.GL_TEXTURE1);
 				gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, srcTexture);
 
-				ShaderProgram program = _shaders.getProgram(BlendModeShaders.class, blendMode.name());
+				IShaderProgram program = _shaders.getProgram(BlendModeShaders.class, blendMode.name());
 				synchronized (program) {
 					gl.glUseProgram(program.getProgram());
 					gl.glUniform1i(program.getUniformLocation("texDst"), 0);
@@ -594,7 +591,7 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 					if (i >= nLayers) break;
 				}
 
-				ShaderProgram program = _shaders.getProgram(BlendModeShaders.class, "INTERSECTING_BLEND");
+				IShaderProgram program = _shaders.getProgram(BlendModeShaders.class, "INTERSECTING_BLEND");
 				synchronized (program) {
 					gl.glUseProgram(program.getProgram());
 					gl.glUniform1i(program.getUniformLocation("nLayers"), nLayers);
@@ -990,7 +987,11 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 		});
 	}
 
-	public void renderText(final FTGLfont font, final Color fillColor, final String text, VideoBuffer resultBuffer) {
+	public void renderText(
+			final FTGLfont font, final Color fillColor,
+			final String[] texts, final double[][] offsets,
+			VideoBuffer resultBuffer) {
+
 		final int resultTexture = resultBuffer.getTexture();
 		final VideoBounds resultBounds = resultBuffer.getBounds();
 
@@ -999,11 +1000,13 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 				GL gl = _vrContext.getGL();
 				GLU glu = _vrContext.getGLU();
 
+				float scale = (float) _vrContext.getRenderResolution().scale;
+
 				ortho2D(gl, glu, resultBounds.width, resultBounds.height);
 				gl.glTranslatef((float) -resultBounds.x, (float) -resultBounds.y, 0);
 
-				float scale = (float) _vrContext.getRenderResolution().scale;
-				gl.glScalef(scale, -scale, scale);
+				double[] mvMatrix = new double[16];
+				getMatrix(mvMatrix, null);
 
 				gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
 						GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, resultTexture, 0);
@@ -1020,9 +1023,14 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 				// オリジナルのFTGLは内部でアルファブレンドの設定を行っているが、Javieはそれを無効にした修正版FTGLを使用している。
 				// Javieには次のアルファブレンドが必要なため。
 				gl.glEnable(GL.GL_BLEND);
-				gl.glBlendFuncSeparate(GL.GL_SRC_ALPHA, GL.GL_ZERO, GL.GL_ONE, GL.GL_ZERO);
+				gl.glBlendFuncSeparate(GL.GL_SRC_ALPHA, GL.GL_ONE_MINUS_SRC_ALPHA, GL.GL_ONE, GL.GL_ONE_MINUS_SRC_ALPHA);
 
-				FTGL.instance.ftglRenderFont(font, text, FTGL.FTGL_RENDER_ALL);
+				for (int i = 0; i < texts.length; ++i) {
+					setMatrix(mvMatrix, null);
+					gl.glTranslatef((float)offsets[i][0], (float)offsets[i][1], 0);
+					gl.glScalef(scale, -scale, scale);
+					FTGL.ftglRenderFont(font, texts[i], FTGL.FTGL_RENDER_ALL);
+				}
 
 				gl.glDisable(GL.GL_BLEND);
 
@@ -1037,7 +1045,8 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 	}
 
 	public void renderText(
-			final FTGLfont font, final Color fillColor, final String text,
+			final FTGLfont font, final Color fillColor,
+			final String[] texts, final double[][] offsets,
 			VideoBuffer resultBuffer, DepthBuffer depthBuffer,
 			final double[] mvMatrix, final double[] prjMatrix) {
 
@@ -1051,14 +1060,16 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 			public Object execute() {
 				GL gl = _vrContext.getGL();
 
+				float scale = (float) _vrContext.getRenderResolution().scale;
+
 				gl.glViewport(0, 0, resultImageSize.width, resultImageSize.height);
 				gl.glMatrixMode(GL.GL_PROJECTION);
 				gl.glLoadMatrixd(prjMatrix, 0);
 				gl.glMatrixMode(GL.GL_MODELVIEW);
 				gl.glLoadMatrixd(mvMatrix, 0);
 
-				float scale = (float) _vrContext.getRenderResolution().scale;
-				gl.glScalef(scale, -scale, scale);
+				double[] mvMatrix = new double[16];
+				getMatrix(mvMatrix, null);
 
 
 				gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
@@ -1085,7 +1096,12 @@ public class VideoRenderSupportImpl implements VideoRenderSupport {
 				float b = (float)fillColor.b * a;
 				gl.glColor4f(r, g, b, a);
 
-				FTGL.instance.ftglRenderFont(font, text, FTGL.FTGL_RENDER_ALL);
+				for (int i = 0; i < texts.length; ++i) {
+					setMatrix(mvMatrix, null);
+					gl.glTranslatef((float)offsets[i][0], (float)offsets[i][1], 0);
+					gl.glScalef(scale, -scale, scale);
+					FTGL.ftglRenderFont(font, texts[i], FTGL.FTGL_RENDER_ALL);
+				}
 
 				if (depthTexture != 0) {
 					gl.glDisable(GL.GL_DEPTH_TEST);
