@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -27,9 +27,10 @@ import java.util.List;
 
 import ch.kuramo.javie.core.AudioBuffer;
 import ch.kuramo.javie.core.Effect;
+import ch.kuramo.javie.core.WrappedOperation;
 
 public interface AudioEffectPipeline {
 
-	AudioBuffer doAudioEffects(List<Effect> effects, AudioBuffer inputBuffer);
+	AudioBuffer doAudioEffects(List<Effect> effects, WrappedOperation<AudioBuffer> inputOperation);
 
 }
