@@ -27,6 +27,7 @@ import java.util.Collection;
 
 import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.ColorMode;
+import ch.kuramo.javie.api.IArray;
 import ch.kuramo.javie.api.Size2i;
 import ch.kuramo.javie.api.Vec3d;
 import ch.kuramo.javie.api.VideoBounds;
@@ -54,9 +55,7 @@ public interface VideoRenderSupport {
 	void deleteTexture(int texture);
 
 
-	Object createArray(ColorMode colorMode, Size2i imageSize);
-
-	void releaseArray(Object array);
+	IArray<?> createArray(ColorMode colorMode, Size2i imageSize);
 
 
 	void copyArrayToTexture(Object array, int texture, ColorMode colorMode, Size2i imageSize);
@@ -113,10 +112,11 @@ public interface VideoRenderSupport {
 
 	void scaleAndFlipVertical(VideoBuffer srcBuffer, VideoBuffer resultBuffer, double scale);
 
-	void renderText(FTGLfont font, Color fillColor, String text, VideoBuffer resultBuffer);
+	void renderText(FTGLfont font, Color fillColor, String[] texts, double[][] offsets, VideoBuffer resultBuffer);
 
 	void renderText(
-			FTGLfont font, Color fillColor, String text,
+			FTGLfont font, Color fillColor,
+			String[] texts, double[][] offsets,
 			VideoBuffer resultBuffer, DepthBuffer depthBuffer,
 			double[] mvMatrix, double[] prjMatrix);
 
