@@ -148,7 +148,7 @@ JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_MacOSXQTCoreVideoInput
 
 JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_MacOSXQTCoreVideoInput_audioChunkFromTime
 (JNIEnv* env, jobject jthis, jlong audioInputAddress,
- jlong timeValue, jint timeScale, jobject byteArray, jint frameCount)
+ jlong timeValue, jint timeScale, jobject byteArray, jint offset, jint frameCount)
 {
 	NSAutoreleasePool* pool = [[NSAutoreleasePool alloc] init];
 	
@@ -156,7 +156,7 @@ JNIEXPORT jint JNICALL Java_ch_kuramo_javie_core_internal_MacOSXQTCoreVideoInput
 	
 	AudioInput* audioInput = POINTER(AudioInput*, audioInputAddress);
 	jint error = [audioInput audioChunkFromTime:QTMakeTime(timeValue, timeScale)
-										 buffer:buffer frameCount:frameCount];
+										 buffer:buffer offset:offset frameCount:frameCount];
 	
 	(*env)->ReleasePrimitiveArrayCritical(env, byteArray, buffer, 0);
 	
