@@ -26,13 +26,13 @@ package ch.kuramo.javie.effects;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.GLProgram;
 import ch.kuramo.javie.api.annotations.GLShader;
 import ch.kuramo.javie.api.annotations.GLShader.ShaderType;
-import ch.kuramo.javie.api.plugin.PIShaderProgram;
-import ch.kuramo.javie.api.plugin.PIShaderRegistry;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
+import ch.kuramo.javie.api.services.IShaderRegistry;
 
 public class VideoEffectUtil {
 
@@ -77,9 +77,9 @@ public class VideoEffectUtil {
 
 
 	public static void convolution1D(
-			PIVideoBuffer src, PIVideoBuffer dst,
+			IVideoBuffer src, IVideoBuffer dst,
 			boolean horizontal, int radius, float[] kernel,
-			GL gl, GLU glu, PIShaderRegistry shaders) {
+			GL gl, GLU glu, IShaderRegistry shaders) {
 
 		VideoBounds srcBounds = src.getBounds();
 		VideoBounds dstBounds = dst.getBounds();
@@ -98,7 +98,7 @@ public class VideoEffectUtil {
 		gl.glActiveTexture(GL.GL_TEXTURE0);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, src.getTexture());
 
-		PIShaderProgram program = shaders.getProgram(
+		IShaderProgram program = shaders.getProgram(
 				VideoEffectUtil.class, horizontal ? "CONVOLUTION_1D_H" : "CONVOLUTION_1D_V");
 		synchronized (program) {
 			gl.glUseProgram(program.getProgram());
@@ -149,9 +149,9 @@ public class VideoEffectUtil {
 	};
 
 	public static void convolution(
-			PIVideoBuffer src, PIVideoBuffer dst,
+			IVideoBuffer src, IVideoBuffer dst,
 			int ksize, float[] kernel, float[] offset,
-			GL gl, GLU glu, PIShaderRegistry shaders) {
+			GL gl, GLU glu, IShaderRegistry shaders) {
 
 		VideoBounds srcBounds = src.getBounds();
 		VideoBounds dstBounds = dst.getBounds();
@@ -170,7 +170,7 @@ public class VideoEffectUtil {
 		gl.glActiveTexture(GL.GL_TEXTURE0);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, src.getTexture());
 
-		PIShaderProgram program = shaders.getProgram(VideoEffectUtil.class, "CONVOLUTION");
+		IShaderProgram program = shaders.getProgram(VideoEffectUtil.class, "CONVOLUTION");
 		synchronized (program) {
 			gl.glUseProgram(program.getProgram());
 			gl.glUniform1i(program.getUniformLocation("texture"), 0);
@@ -218,35 +218,35 @@ public class VideoEffectUtil {
 				bounds.width + dw, bounds.height + dh);
 	}
 
-	public static void setNearest(PIVideoBuffer vb, GL gl) {
+	public static void setNearest(IVideoBuffer vb, GL gl) {
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture());
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MIN_FILTER, GL.GL_NEAREST);
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MAG_FILTER, GL.GL_NEAREST);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
 	}
 
-	public static void setLinear(PIVideoBuffer vb, GL gl) {
+	public static void setLinear(IVideoBuffer vb, GL gl) {
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture());
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MIN_FILTER, GL.GL_LINEAR);
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_MAG_FILTER, GL.GL_LINEAR);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
 	}
 
-	public static void setClampToEdge(PIVideoBuffer vb, GL gl) {
+	public static void setClampToEdge(IVideoBuffer vb, GL gl) {
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture());
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_WRAP_S, GL.GL_CLAMP_TO_EDGE);
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_WRAP_T, GL.GL_CLAMP_TO_EDGE);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
 	}
 
-	public static void setClampToBorder(PIVideoBuffer vb, GL gl) {
+	public static void setClampToBorder(IVideoBuffer vb, GL gl) {
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture());
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_WRAP_S, GL.GL_CLAMP_TO_BORDER);
 		gl.glTexParameteri(GL.GL_TEXTURE_RECTANGLE_EXT, GL.GL_TEXTURE_WRAP_T, GL.GL_CLAMP_TO_BORDER);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, 0);
 	}
 
-	public static void clearTexture(PIVideoBuffer vb, GL gl) {
+	public static void clearTexture(IVideoBuffer vb, GL gl) {
 		if (vb.isArray()) {
 			throw new IllegalArgumentException();
 		}
@@ -262,6 +262,31 @@ public class VideoEffectUtil {
 				GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
 	}
 
+	// TODO VideoRenderSupportImplにもほぼ同じものがあるので整理する。
+	public static void premultiply(IVideoBuffer vb, GL gl, GLU glu) {
+		VideoBounds bounds = vb.getBounds();
+		ortho2D(gl, glu, bounds.width, bounds.height);
+
+		gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
+				GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, vb.getTexture(), 0);
+		gl.glDrawBuffer(GL.GL_COLOR_ATTACHMENT0_EXT);
+
+		gl.glEnable(GL.GL_BLEND);
+		gl.glBlendFuncSeparate(GL.GL_ZERO, GL.GL_DST_ALPHA, GL.GL_ZERO, GL.GL_ONE);
+
+		gl.glBegin(GL.GL_QUADS);
+		gl.glVertex2f(0, 0);
+		gl.glVertex2f(bounds.width, 0);
+		gl.glVertex2f(bounds.width, bounds.height);
+		gl.glVertex2f(0, bounds.height);
+		gl.glEnd();
+
+		gl.glDisable(GL.GL_BLEND);
+
+		gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
+				GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
+	}
+
 
 	private VideoEffectUtil() { }
 
