@@ -26,10 +26,10 @@ package ch.kuramo.javie.effects.blurSharpen;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
-import ch.kuramo.javie.api.plugin.PIShaderProgram;
-import ch.kuramo.javie.api.plugin.PIShaderRegistry;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
+import ch.kuramo.javie.api.services.IShaderRegistry;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 public class BlurUtil {
@@ -58,8 +58,8 @@ public class BlurUtil {
 	}
 
 	public static void doDownSample(
-			PIVideoBuffer src, PIVideoBuffer dst, int hRatio, int vRatio,
-			GL gl, GLU glu, PIShaderRegistry shaders) {
+			IVideoBuffer src, IVideoBuffer dst, int hRatio, int vRatio,
+			GL gl, GLU glu, IShaderRegistry shaders) {
 
 		int ksize = hRatio * vRatio;
 		float[] kernel = new float[ksize];
@@ -89,7 +89,7 @@ public class BlurUtil {
 		gl.glActiveTexture(GL.GL_TEXTURE0);
 		gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, src.getTexture());
 
-		PIShaderProgram program = shaders.getProgram(VideoEffectUtil.class, "CONVOLUTION");
+		IShaderProgram program = shaders.getProgram(VideoEffectUtil.class, "CONVOLUTION");
 		synchronized (program) {
 			gl.glUseProgram(program.getProgram());
 			gl.glUniform1i(program.getUniformLocation("texture"), 0);
@@ -120,7 +120,7 @@ public class BlurUtil {
 	}
 
 	public static void doUpSample(
-			PIVideoBuffer src, PIVideoBuffer dst,
+			IVideoBuffer src, IVideoBuffer dst,
 			int hRatio, int vRatio, GL gl, GLU glu) {
 
 		VideoBounds srcBounds = src.getBounds();
