@@ -27,18 +27,18 @@ import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
 import ch.kuramo.javie.api.Color;
+import ch.kuramo.javie.api.IAnimatableColor;
+import ch.kuramo.javie.api.IAnimatableDouble;
+import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.GLProgram;
 import ch.kuramo.javie.api.annotations.GLShader;
 import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.GLShader.ShaderType;
-import ch.kuramo.javie.api.plugin.PIAnimatableColor;
-import ch.kuramo.javie.api.plugin.PIAnimatableDouble;
-import ch.kuramo.javie.api.plugin.PIShaderProgram;
-import ch.kuramo.javie.api.plugin.PIShaderRegistry;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
-import ch.kuramo.javie.api.plugin.PIVideoRenderContext;
+import ch.kuramo.javie.api.services.IShaderRegistry;
+import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 import com.google.inject.Inject;
@@ -75,32 +75,31 @@ public class Tritone {
 	};
 
 
-	private final PIVideoRenderContext context;
+	private final IVideoEffectContext context;
 
-	private final PIShaderProgram tritoneProgram;
+	private final IShaderProgram tritoneProgram;
 
-	@Property("1.0,1.0,1.0")
-	private PIAnimatableColor highlight;
+	@Property("1,1,1")
+	private IAnimatableColor highlight;
 
 	@Property("0.499,0.393,0.275")
-	private PIAnimatableColor midtone;
+	private IAnimatableColor midtone;
 
-	@Property("0.0,0.0,0.0")
-	private PIAnimatableColor shadow;
+	@Property("0,0,0")
+	private IAnimatableColor shadow;
 
-	@Property("0.0")
-	private PIAnimatableDouble blendWithOriginal;
+	@Property(min="0", max="100")
+	private IAnimatableDouble blendWithOriginal;
 
 
 	@Inject
-	public Tritone(PIVideoRenderContext context, PIShaderRegistry shaders) {
+	public Tritone(IVideoEffectContext context, IShaderRegistry shaders) {
 		this.context = context;
 		tritoneProgram = shaders.getProgram(Tritone.class, "TRITONE");
 	}
 
-	public PIVideoBuffer doVideoEffect() {
-		// TODO 値の範囲制限は @Property アノテーションで行う。
-		double blend = Math.max(0, Math.min(1, context.value(blendWithOriginal)/100));
+	public IVideoBuffer doVideoEffect() {
+		double blend = context.value(blendWithOriginal)/100;
 		if (blend == 1) {
 			return null;
 		}
@@ -109,8 +108,8 @@ public class Tritone {
 		Color midtone = context.value(this.midtone);
 		Color shadow = context.value(this.shadow);
 
-		PIVideoBuffer input = context.doPreviousEffect();
-		PIVideoBuffer buf = null;
+		IVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer buf = null;
 		try {
 			VideoBounds bounds = input.getBounds();
 			int w = bounds.width;
@@ -159,7 +158,7 @@ public class Tritone {
 			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
 					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
 
-			PIVideoBuffer output = buf;
+			IVideoBuffer output = buf;
 			buf = null;
 			return output;
 
