@@ -26,18 +26,18 @@ package ch.kuramo.javie.effects.distort;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IAnimatableDouble;
+import ch.kuramo.javie.api.IAnimatableEnum;
+import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.GLProgram;
 import ch.kuramo.javie.api.annotations.GLShader;
 import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.GLShader.ShaderType;
-import ch.kuramo.javie.api.plugin.PIAnimatableDouble;
-import ch.kuramo.javie.api.plugin.PIAnimatableEnum;
-import ch.kuramo.javie.api.plugin.PIShaderProgram;
-import ch.kuramo.javie.api.plugin.PIShaderRegistry;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
-import ch.kuramo.javie.api.plugin.PIVideoRenderContext;
+import ch.kuramo.javie.api.services.IShaderRegistry;
+import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 import com.google.inject.Inject;
@@ -95,39 +95,38 @@ public class PolarCoordinates {
 	public enum TypeOfConversion { RECT_TO_POLAR, POLAR_TO_RECT }
 
 
-	private final PIVideoRenderContext context;
+	private final IVideoEffectContext context;
 
-	private final PIShaderProgram rectToPolarProgram;
+	private final IShaderProgram rectToPolarProgram;
 
-	private final PIShaderProgram polarToRectProgram;
+	private final IShaderProgram polarToRectProgram;
+
+	@Property(min="0", max="100")
+	private IAnimatableDouble interpolation;
 
 	@Property
-	private PIAnimatableDouble interpolation;
-
-	@Property
-	private PIAnimatableEnum<TypeOfConversion> typeOfConversion;
+	private IAnimatableEnum<TypeOfConversion> typeOfConversion;
 
 
 	@Inject
-	public PolarCoordinates(PIVideoRenderContext context, PIShaderRegistry shaders) {
+	public PolarCoordinates(IVideoEffectContext context, IShaderRegistry shaders) {
 		this.context = context;
 		rectToPolarProgram = shaders.getProgram(PolarCoordinates.class, "RECT_TO_POLAR");
 		polarToRectProgram = shaders.getProgram(PolarCoordinates.class, "POLAR_TO_RECT");
 	}
 
-	public PIVideoBuffer doVideoEffect() {
-		// TODO 値の範囲制限は @Property アノテーションで行う。
-		double interp = Math.max(0, Math.min(1, context.value(this.interpolation)/100));
+	public IVideoBuffer doVideoEffect() {
+		double interp = context.value(this.interpolation)/100;
 		if (interp == 0) {
 			return null;
 		}
 
 		TypeOfConversion type = context.value(this.typeOfConversion);
-		PIShaderProgram program = (type == TypeOfConversion.RECT_TO_POLAR)
+		IShaderProgram program = (type == TypeOfConversion.RECT_TO_POLAR)
 				? rectToPolarProgram : polarToRectProgram;
 
-		PIVideoBuffer input = context.doPreviousEffect();
-		PIVideoBuffer buffer = null;
+		IVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer buffer = null;
 		try {
 			VideoBounds bounds = input.getBounds();
 			int w = bounds.width;
@@ -178,7 +177,7 @@ public class PolarCoordinates {
 			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
 					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
 
-			PIVideoBuffer output = buffer;
+			IVideoBuffer output = buffer;
 			buffer = null;
 			return output;
 
