@@ -26,31 +26,31 @@ package ch.kuramo.javie.effects.keying;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IAnimatableBoolean;
+import ch.kuramo.javie.api.IAnimatableDouble;
+import ch.kuramo.javie.api.IAnimatableEnum;
+import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
-import ch.kuramo.javie.api.plugin.PIAnimatableBoolean;
-import ch.kuramo.javie.api.plugin.PIAnimatableDouble;
-import ch.kuramo.javie.api.plugin.PIAnimatableEnum;
-import ch.kuramo.javie.api.plugin.PIShaderProgram;
-import ch.kuramo.javie.api.plugin.PIShaderRegistry;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
-import ch.kuramo.javie.api.plugin.PIVideoRenderContext;
+import ch.kuramo.javie.api.services.IShaderRegistry;
+import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 public abstract class BlueGreenScreenKeyBase {
 
-	private final PIVideoRenderContext context;
+	private final IVideoEffectContext context;
 
-	private final PIShaderProgram keyingProgram;
+	private final IShaderProgram keyingProgram;
 
-	private final PIShaderProgram maskOnlyProgram;
+	private final IShaderProgram maskOnlyProgram;
 
-	private final PIShaderProgram smoothingLowProgram;
+	private final IShaderProgram smoothingLowProgram;
 
-	private final PIShaderProgram smoothingHighProgram;
+	private final IShaderProgram smoothingHighProgram;
 
 
 	protected BlueGreenScreenKeyBase(
-			PIVideoRenderContext context, PIShaderRegistry shaders, boolean blue) {
+			IVideoEffectContext context, IShaderRegistry shaders, boolean blue) {
 
 		this.context = context;
 
@@ -66,21 +66,17 @@ public abstract class BlueGreenScreenKeyBase {
 		smoothingHighProgram = shaders.getProgram(KeyingShaders.class, "SMOOTHING_HIGH");
 	}
 
-	protected PIVideoBuffer doKeying(
-			PIAnimatableDouble threshold,
-			PIAnimatableDouble cutoff,
-			PIAnimatableBoolean maskOnly,
-			PIAnimatableEnum<Smoothing> smoothing) {
+	protected IVideoBuffer doKeying(
+			IAnimatableDouble threshold,
+			IAnimatableDouble cutoff,
+			IAnimatableBoolean maskOnly,
+			IAnimatableEnum<Smoothing> smoothing) {
 
 		double t = context.value(threshold) / 100;
 		double c = context.value(cutoff) / 100;
 		boolean mask = context.value(maskOnly);
 		Smoothing sm = mask ? Smoothing.NONE : context.value(smoothing);
 
-		// TODO 値の範囲制限は @Property アノテーションで行う。
-		t = Math.max(0, Math.min(1, t));
-		c = Math.max(0, Math.min(1, c));
-
 		double t_minus_c = t - c;
 		if (t_minus_c == 0) {
 			if (t == 0) {
@@ -90,8 +86,8 @@ public abstract class BlueGreenScreenKeyBase {
 			}
 		}
 
-		PIVideoBuffer input = context.doPreviousEffect();
-		PIVideoBuffer buf = null;
+		IVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer buf = null;
 		try {
 			VideoBounds bounds = input.getBounds();
 			int w = bounds.width;
@@ -111,7 +107,7 @@ public abstract class BlueGreenScreenKeyBase {
 			gl.glActiveTexture(GL.GL_TEXTURE0);
 			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, input.getTexture());
 
-			PIShaderProgram program = mask ? maskOnlyProgram : keyingProgram;
+			IShaderProgram program = mask ? maskOnlyProgram : keyingProgram;
 			synchronized (program) {
 				gl.glUseProgram(program.getProgram());
 				gl.glUniform1i(program.getUniformLocation("texture"), 0);
@@ -140,7 +136,7 @@ public abstract class BlueGreenScreenKeyBase {
 			}
 
 			if (program != null) {
-				PIVideoBuffer tmp = input;
+				IVideoBuffer tmp = input;
 				input = buf;
 				buf = tmp;
 
@@ -174,7 +170,7 @@ public abstract class BlueGreenScreenKeyBase {
 			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
 					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
 
-			PIVideoBuffer output = buf;
+			IVideoBuffer output = buf;
 			buf = null;
 			return output;
 
