@@ -26,18 +26,18 @@ package ch.kuramo.javie.effects.stylize;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IAnimatableBoolean;
+import ch.kuramo.javie.api.IAnimatableInteger;
+import ch.kuramo.javie.api.IShaderProgram;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.GLProgram;
 import ch.kuramo.javie.api.annotations.GLShader;
 import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.GLShader.ShaderType;
-import ch.kuramo.javie.api.plugin.PIAnimatableBoolean;
-import ch.kuramo.javie.api.plugin.PIAnimatableInteger;
-import ch.kuramo.javie.api.plugin.PIShaderProgram;
-import ch.kuramo.javie.api.plugin.PIShaderRegistry;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
-import ch.kuramo.javie.api.plugin.PIVideoRenderContext;
+import ch.kuramo.javie.api.services.IShaderRegistry;
+import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 import com.google.inject.Inject;
@@ -61,33 +61,32 @@ public class Mosaic {
 	};
 
 
-	private final PIVideoRenderContext context;
+	private final IVideoEffectContext context;
 
-	private final PIShaderRegistry shaders;
+	private final IShaderRegistry shaders;
 
-	private final PIShaderProgram sharpColorsProgram;
+	private final IShaderProgram sharpColorsProgram;
 
-	@Property("10")
-	private PIAnimatableInteger horizontalBlocks;
+	@Property(value="10", min="1")
+	private IAnimatableInteger horizontalBlocks;
 
-	@Property("10")
-	private PIAnimatableInteger verticalBlocks;
+	@Property(value="10", min="1")
+	private IAnimatableInteger verticalBlocks;
 
 	@Property
-	private PIAnimatableBoolean sharpColors;
+	private IAnimatableBoolean sharpColors;
 
 
 	@Inject
-	public Mosaic(PIVideoRenderContext context, PIShaderRegistry shaders) {
+	public Mosaic(IVideoEffectContext context, IShaderRegistry shaders) {
 		this.context = context;
 		this.shaders = shaders;
 		this.sharpColorsProgram = shaders.getProgram(Mosaic.class, "MOSAIC_SHARP_COLORS");
 	}
 
-	public PIVideoBuffer doVideoEffect() {
-		// TODO 値の範囲制限は @Property アノテーションで行う。
-		int hBlocks = Math.max(1, context.value(horizontalBlocks));
-		int vBlocks = Math.max(1, context.value(verticalBlocks));
+	public IVideoBuffer doVideoEffect() {
+		int hBlocks = context.value(horizontalBlocks);
+		int vBlocks = context.value(verticalBlocks);
 		boolean sharpColors = context.value(this.sharpColors);
 
 		if (sharpColors) {
@@ -97,8 +96,8 @@ public class Mosaic {
 		}
 	}
 
-	private PIVideoBuffer doSharpColorsMosaic(int hBlocks, int vBlocks) {
-		PIVideoBuffer input = context.doPreviousEffect();
+	private IVideoBuffer doSharpColorsMosaic(int hBlocks, int vBlocks) {
+		IVideoBuffer input = context.doPreviousEffect();
 		VideoBounds bounds = input.getBounds();
 		int w = bounds.width;
 		int h = bounds.height;
@@ -110,7 +109,7 @@ public class Mosaic {
 			return input;
 		}
 
-		PIVideoBuffer buffer = null;
+		IVideoBuffer buffer = null;
 		try {
 			buffer = context.createVideoBuffer(bounds);
 
@@ -153,7 +152,7 @@ public class Mosaic {
 			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
 					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
 
-			PIVideoBuffer output = buffer;
+			IVideoBuffer output = buffer;
 			buffer = null;
 			return output;
 
@@ -163,9 +162,9 @@ public class Mosaic {
 		}
 	}
 
-	private PIVideoBuffer doAverageColorsMosaic(int hBlocks, int vBlocks) {
-		PIVideoBuffer input = context.doPreviousEffect();
-		PIVideoBuffer buffer = null;
+	private IVideoBuffer doAverageColorsMosaic(int hBlocks, int vBlocks) {
+		IVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer buffer = null;
 		try {
 			VideoBounds bounds = input.getBounds();
 			int w = bounds.width;
@@ -180,7 +179,7 @@ public class Mosaic {
 				scale(buffer, input);
 			}
 
-			PIVideoBuffer output = input;
+			IVideoBuffer output = input;
 			input = null;
 			return output;
 
@@ -190,12 +189,12 @@ public class Mosaic {
 		}
 	}
 
-	private void average(PIVideoBuffer src, PIVideoBuffer dst) {
+	private void average(IVideoBuffer src, IVideoBuffer dst) {
 		GL gl = context.getGL();
 		GLU glu = context.getGLU();
 
-		PIVideoBuffer src0 = src;
-		PIVideoBuffer tmpBuf = null;
+		IVideoBuffer src0 = src;
+		IVideoBuffer tmpBuf = null;
 		try {
 			VideoBounds srcBounds = src.getBounds();
 			VideoBounds dstBounds = dst.getBounds();
@@ -240,7 +239,7 @@ public class Mosaic {
 			gl.glActiveTexture(GL.GL_TEXTURE0);
 			gl.glBindTexture(GL.GL_TEXTURE_RECTANGLE_EXT, src.getTexture());
 
-			PIShaderProgram program = shaders.getProgram(VideoEffectUtil.class, "CONVOLUTION");
+			IShaderProgram program = shaders.getProgram(VideoEffectUtil.class, "CONVOLUTION");
 			synchronized (program) {
 				gl.glUseProgram(program.getProgram());
 				gl.glUniform1i(program.getUniformLocation("texture"), 0);
@@ -275,7 +274,7 @@ public class Mosaic {
 		}
 	}
 
-	private void scale(PIVideoBuffer src, PIVideoBuffer dst) {
+	private void scale(IVideoBuffer src, IVideoBuffer dst) {
 		GL gl = context.getGL();
 		GLU glu = context.getGLU();
 
