@@ -29,13 +29,14 @@ import java.util.Arrays;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IAnimatableDouble;
+import ch.kuramo.javie.api.IArray;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.Property;
-import ch.kuramo.javie.api.plugin.PIAnimatableDouble;
-import ch.kuramo.javie.api.plugin.PIArrayPools;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
-import ch.kuramo.javie.api.plugin.PIVideoRenderContext;
+import ch.kuramo.javie.api.services.IArrayPools;
+import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 import com.google.inject.Inject;
@@ -43,35 +44,34 @@ import com.google.inject.Inject;
 @Effect(id="ch.kuramo.javie.LinearWipe", category=Effect.TRANSITION)
 public class LinearWipe {
 
-	private final PIVideoRenderContext context;
+	private final IVideoEffectContext context;
 
-	private final PIArrayPools arrayPools;
+	private final IArrayPools arrayPools;
 
-	@Property
-	private PIAnimatableDouble transitionCompletion;
+	@Property(min="0", max="100")
+	private IAnimatableDouble transitionCompletion;
 
 	@Property("90")
-	private PIAnimatableDouble wipeAngle;
+	private IAnimatableDouble wipeAngle;
 
-	@Property
-	private PIAnimatableDouble feather;
+	@Property(min="0", max="32000")
+	private IAnimatableDouble feather;
 
 
 	@Inject
-	public LinearWipe(PIVideoRenderContext context, PIArrayPools arrayPools) {
+	public LinearWipe(IVideoEffectContext context, IArrayPools arrayPools) {
 		this.context = context;
 		this.arrayPools = arrayPools;
 	}
 
-	public PIVideoBuffer doVideoEffect() {
-		// TODO 値の範囲制限は @Property アノテーションで行う。
-		double completion = Math.max(0, Math.min(1, context.value(transitionCompletion)/100));
+	public IVideoBuffer doVideoEffect() {
+		double completion = context.value(transitionCompletion)/100;
 		if (completion == 0) {
 			return null;
 		} else if (completion == 1) {
 			// TODO context.doPreviousEffect()をしなくてもVideoBoundsを取得できる方法が必要。
 			//      context.getPreviousBounds()をここで呼ぶとIllegalStateExceptionが発生する。
-			PIVideoBuffer vb = context.doPreviousEffect();
+			IVideoBuffer vb = context.doPreviousEffect();
 			VideoEffectUtil.clearTexture(vb, context.getGL());
 			return vb;
 		}
@@ -79,12 +79,11 @@ public class LinearWipe {
 		double wipeAngle = context.value(this.wipeAngle) % 360;
 		if (wipeAngle < 0) wipeAngle += 360;
 
-		// TODO 値の範囲制限は @Property アノテーションで行う。
-		double feather = Math.max(0, context.value(this.feather));
+		double feather = context.value(this.feather);
 		feather = context.getRenderResolution().scale(feather);
 
 
-		PIVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer input = context.doPreviousEffect();
 		VideoBounds bounds = input.getBounds();
 		int w = bounds.width;
 		int h = bounds.height;
@@ -154,26 +153,28 @@ public class LinearWipe {
 		float completionPoint = intFeather + (wipeLen+2*intFeather) * completion;
 		int completionIndex = (int) completionPoint;
 
-		float[] tmpData = arrayPools.getFloatArray(tmpDataLen);
-		float[] wipeData = null;
-		float[] kernel = null;
+		IArray<float[]> tmpArray = arrayPools.getFloatArray(tmpDataLen);
+		IArray<float[]> wipeArray = null;
+		IArray<float[]> kernelArray = null;
 
 		try {
+			float[] tmpData = tmpArray.getArray();
 			FloatBuffer buffer;
+
 			if (completionIndex+intFeather == tmpDataLen) {
 				// ArrayPoolsから取得した配列はゼロクリアされていないのでクリアする必要がある。
-				Arrays.fill(tmpData, 0);
-				buffer = FloatBuffer.wrap(tmpData);
+				Arrays.fill(tmpData, 0, tmpDataLen, 0f);
+				buffer = FloatBuffer.wrap(tmpData, 0, tmpDataLen);
 
 			} else if (tmpDataLen == wipeLen) {
 				Arrays.fill(tmpData, 0, completionIndex, 0f);
 				tmpData[completionIndex] = 1 - (completionPoint - completionIndex);
 				Arrays.fill(tmpData, completionIndex+1, tmpDataLen, 1f);
-				buffer = FloatBuffer.wrap(tmpData);
+				buffer = FloatBuffer.wrap(tmpData, 0, tmpDataLen);
 
 			} else {
 				int kernelLen = intFeather*2+1;
-				kernel = arrayPools.getFloatArray(kernelLen);
+				float[] kernel = (kernelArray = arrayPools.getFloatArray(kernelLen)).getArray();
 
 				float sigma = feather / 2.5f;
 				float sigmaSquare = sigma * sigma;
@@ -199,9 +200,9 @@ public class LinearWipe {
 
 				Arrays.fill(tmpData, completionIndex+intFeather+1, tmpDataLen, 1f);
 
-				wipeData = arrayPools.getFloatArray(wipeLen);
+				float[] wipeData = (wipeArray = arrayPools.getFloatArray(wipeLen)).getArray();
 				System.arraycopy(tmpData, 2*intFeather, wipeData, 0, wipeLen);
-				buffer = FloatBuffer.wrap(wipeData);
+				buffer = FloatBuffer.wrap(wipeData, 0, wipeLen);
 			}
 
 			switch (context.getColorMode()) {
@@ -225,9 +226,9 @@ public class LinearWipe {
 					throw new RuntimeException("unknown ColorMode: " + context.getColorMode());
 			}
 		} finally {
-			arrayPools.put(tmpData);
-			arrayPools.put(wipeData);
-			arrayPools.put(kernel);
+			tmpArray.release();
+			if (wipeArray != null) wipeArray.release();
+			if (kernelArray != null) kernelArray.release();
 		}
 	}
 
