@@ -26,13 +26,13 @@ package ch.kuramo.javie.effects.utility;
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
+import ch.kuramo.javie.api.IAnimatableInteger;
+import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.RenderResolution;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.Property;
-import ch.kuramo.javie.api.plugin.PIAnimatableInteger;
-import ch.kuramo.javie.api.plugin.PIVideoBuffer;
-import ch.kuramo.javie.api.plugin.PIVideoRenderContext;
+import ch.kuramo.javie.api.services.IVideoEffectContext;
 import ch.kuramo.javie.effects.VideoEffectUtil;
 
 import com.google.inject.Inject;
@@ -40,23 +40,23 @@ import com.google.inject.Inject;
 @Effect(id="ch.kuramo.javie.ChangeBounds", category=Effect.UTILITY)
 public class ChangeBounds {
 
-	private final PIVideoRenderContext context;
+	private final IVideoEffectContext context;
 
-	@Property
-	private PIAnimatableInteger	left;
+	@Property(max="1000")	// TODO 最大値はどのくらいまで許容すればよいだろうか。以下同様。
+	private IAnimatableInteger	left;
 
-	@Property
-	private PIAnimatableInteger	top;
+	@Property(max="1000")
+	private IAnimatableInteger	top;
 
-	@Property
-	private PIAnimatableInteger	right;
+	@Property(max="1000")
+	private IAnimatableInteger	right;
 
-	@Property
-	private PIAnimatableInteger	bottom;
+	@Property(max="1000")
+	private IAnimatableInteger	bottom;
 
 
 	@Inject
-	public ChangeBounds(PIVideoRenderContext context) {
+	public ChangeBounds(IVideoEffectContext context) {
 		this.context = context;
 	}
 
@@ -76,14 +76,14 @@ public class ChangeBounds {
 				Math.max(0, bounds.height + top + bottom));
 	}
 
-	public PIVideoBuffer doVideoEffect() {
+	public IVideoBuffer doVideoEffect() {
 		RenderResolution resolution = context.getRenderResolution();
 		int left = (int) resolution.scale(context.value(this.left));
 		int top = (int) resolution.scale(context.value(this.top));
 		int right = (int) resolution.scale(context.value(this.right));
 		int bottom = (int) resolution.scale(context.value(this.bottom));
 
-		PIVideoBuffer input = context.doPreviousEffect();
+		IVideoBuffer input = context.doPreviousEffect();
 		VideoBounds oldBounds = input.getBounds();
 
 		VideoBounds newBounds = new VideoBounds(
@@ -96,7 +96,7 @@ public class ChangeBounds {
 			return input;
 		}
 
-		PIVideoBuffer buffer = context.createVideoBuffer(newBounds);
+		IVideoBuffer buffer = context.createVideoBuffer(newBounds);
 		try {
 			GL gl = context.getGL();
 			GLU glu = context.getGLU();
@@ -138,7 +138,7 @@ public class ChangeBounds {
 			gl.glFramebufferTexture2DEXT(GL.GL_FRAMEBUFFER_EXT,
 					GL.GL_COLOR_ATTACHMENT0_EXT, GL.GL_TEXTURE_RECTANGLE_EXT, 0, 0);
 
-			PIVideoBuffer output = buffer;
+			IVideoBuffer output = buffer;
 			buffer = null;
 			return output;
 
